(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    197642,       5580]
NotebookOptionsPosition[    175840,       5249]
NotebookOutlinePosition[    176344,       5268]
CellTagsIndexPosition[    176301,       5265]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Code from \"Glimpses of Soliton Theory\" by Alex Kasman (Second Edition)"
}], "Title",
 CellChangeTimes->{{3.443283669134124*^9, 3.443283678035811*^9}, {
  3.866470659665097*^9, 
  3.8664706715008173`*^9}},ExpressionUUID->"932184fb-edc0-4e22-9b2e-\
b17d71a5f2e3"],

Cell[CellGroupData[{

Cell["\<\
All Definitions (execute this section to just define all commands at once)\
\>", "Section",
 CellChangeTimes->{{3.8748463068562803`*^9, 3.8748463651742897`*^9}, {
  3.8748473853712263`*^9, 
  3.874847387370989*^9}},ExpressionUUID->"53450679-dcac-46e7-a69b-\
58eec057524c"],

Cell[CellGroupData[{

Cell["\<\
The  sections below are designed to be read and include discussion or \
examples.  This section, though, just groups all of the definitions in one \
place.  That way, you can execute this section and have all of the definitions\
\>", "Subsection",
 CellChangeTimes->{{3.874846703922098*^9, 3.8748467784271517`*^9}, {
  3.874847552428574*^9, 
  3.874847572953864*^9}},ExpressionUUID->"3ea58a94-b64a-4152-ade8-\
75c2e2c60728"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MyAnimate", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"y0", ",", "y1"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0", ",", "t1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"MyAnimate", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0_", ",", "z1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Plot3D", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "y0", ",", "y1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"z0", ",", "z1"}], "}"}]}], ",", 
       RowBox[{"ColorFunction", "->", "\"\<Aquamarine\>\""}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0", ",", "t1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.874846401437584*^9, 
  3.8748464126493893`*^9}},ExpressionUUID->"55947ec3-25b5-42e1-a643-\
19f26c69e0de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SimpleEvolver", "[", 
    RowBox[{"profile_", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "x0_", ",", " ", "x1_"}], "}"}]}], "]"}], " ", ":=",
    " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"RHS", " ", "=", " ", 
      RowBox[{"profile", " ", 
       RowBox[{"(", 
        RowBox[{"profile", " ", "-", " ", 
         RowBox[{"D", "[", 
          RowBox[{"profile", ",", " ", "x"}], "]"}]}], ")"}]}]}], ";", "\n", 
     "    ", 
     RowBox[{"numpts", " ", "=", " ", "1000"}], ";", "\n", "    ", 
     RowBox[{"tsize", " ", "=", " ", ".1"}], ";", "\n", "    ", 
     RowBox[{"profiletable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{"profile", " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"evolvedtable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"profile", " ", "+", " ", 
             RowBox[{"tsize", " ", "RHS"}]}], " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", "profiletable", "]"}], ",", " ", 
          RowBox[{"Dashing", "[", ".01", "]"}], ",", " ", 
          RowBox[{"Line", "[", "evolvedtable", "]"}]}], "}"}], "]"}], ",", 
       " ", 
       RowBox[{"Axes", " ", "->", " ", "True"}]}], "]"}]}], ")"}]}], 
  "\n"}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.483258785530251*^9, 3.483258796991585*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"b8ba4229-c782-45f1-b208-96a527d0816a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimBurgers", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "a_", ",", "b_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"liszt", ",", "i", ",", "j", ",", "n", ",", "min", ",", "max"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"liszt", "[", "0", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"N", "[", 
           RowBox[{"f", "/.", 
            RowBox[{"x", "\[Rule]", "i"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"a", "-", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{"b", "+", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"min", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"max", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "100"}], ",", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{
        RowBox[{"liszt", "[", "i", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"liszt", "[", 
               RowBox[{"i", "-", "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], "+", 
             RowBox[{".1", " ", 
              RowBox[{
               RowBox[{"liszt", "[", 
                RowBox[{"i", "-", "1"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "2"}], "]"}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"liszt", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"liszt", "[", "0", "]"}], "]"}]}], "}"}]}], "]"}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ListAnimate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"Line", "[", 
              RowBox[{"liszt", "[", "i", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"a", ",", "b"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"min", "-", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}], ",", 
               RowBox[{"max", "+", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}]}], "}"}]}], 
            "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "99", ",", "1"}], "}"}]}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",ExpressionUUID->"ad07b7f3-99bf-465f-8fa1-\
601c5c383059"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KdV", "[", "v_", "]"}], ":=", 
   RowBox[{
   "Print", "[", 
    "\"\<You are supposed to create your own KdV[] command.  Please write \
one. -Alex\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.474190350998053*^9, 
  3.474190403385339*^9}},ExpressionUUID->"cdb206e2-c443-45e5-a50a-\
b0f6d3942dc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"usol", "[", 
   RowBox[{"x_", ",", "t_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"8", 
   RowBox[{
    RowBox[{"k", "^", "2"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"k", " ", "x"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}], "+", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "k"}], " ", "x"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}]}], ")"}], "^", 
     "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.408982782904517*^9, 3.408982800142632*^9}, {
  3.443282835828529*^9, 
  3.4432828367058268`*^9}},ExpressionUUID->"17c173a6-6bfe-4789-9a0a-\
6e2b567132d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2sol", "[", 
   RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"24", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", "x"}], ")"}]}]], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"20", " ", "t"}], "+", 
         RowBox[{"8", " ", "x"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"34", " ", "t"}], "+", 
        RowBox[{"10", " ", "x"}]}]]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}]}], ")"}], 
    "2"]]}]], "Input",
 CellChangeTimes->{{3.443283003726342*^9, 
  3.443283016366675*^9}},ExpressionUUID->"fb4b594f-ff4c-4e25-9d1e-\
1d9a0635b2f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", "z_", "]"}], ":=", 
  RowBox[{"WeierstrassP", "[", 
   RowBox[{"z", ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "18"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.874768141537115*^9, 3.874768153694622*^9}, {
  3.874768361023374*^9, 3.874768361090159*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"5fda82fe-22ed-48ad-846d-729a317d35eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uell", "[", 
   RowBox[{
   "x_", ",", "t_", ",", "c_", ",", "omega_", ",", "k1_", ",", "k2_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"WeierstrassP", "[", 
     RowBox[{
      RowBox[{"x", "+", 
       RowBox[{"c", " ", "t"}], "+", "omega"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "k2"}], "}"}]}], "]"}]}], "+", 
   RowBox[{"2", 
    RowBox[{"c", "/", "3"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.443549062363452*^9, {3.8747690092603188`*^9, 3.874769011778088*^9}, {
   3.874769409007949*^9, 3.874769414013115*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"967422e9-3bbe-4ecb-93a6-57216824853f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"x_", ",", "t_", ",", "gamma2_"}], "]"}], ":=", 
  RowBox[{"Re", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"WeierstrassP", "[", 
      RowBox[{
       RowBox[{"x", " ", "+", " ", "t", " ", "+", " ", "I"}], ",", "\n", 
       "              ", 
       RowBox[{"WeierstrassInvariants", "[", 
        RowBox[{"{", 
         RowBox[{"I", ",", "gamma2"}], "}"}], "]"}]}], " ", "]"}]}], " ", "+",
     " ", 
    RowBox[{"2", "/", "3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.87476864610224*^9, 3.874768646104465*^9}, {
  3.874768969224865*^9, 3.874768972555888*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"bfc780d4-d8c1-455b-a681-abab1584a17f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeu", "[", "tau_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", "tau", " ", 
      RowBox[{"D", "[", 
       RowBox[{"tau", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], "-", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"tau", ",", "x"}], "]"}], "^", "2"}]}]}], ")"}], "/", 
   RowBox[{"tau", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{
  3.4432833269944077`*^9, {3.770389024776661*^9, 3.770389058857048*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"62e0bcd9-5062-4a3d-98d1-66be1210b24d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"c_", ",", "k_"}], "}"}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "+", 
     RowBox[{
      RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}], "+", 
   RowBox[{"c", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "x"}], "-", 
      RowBox[{
       RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}]}]}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"faccaf94-32fc-4506-a8a6-191899c61118"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c1_", ",", "k1_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c2_", ",", "k2_"}], "}"}]}], "}"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"tau1", "=", 
     RowBox[{"maketau", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c1", ",", "k1"}], "}"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tau2", "=", 
     RowBox[{"maketau", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c2", ",", "k2"}], "}"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tau1", " ", 
      RowBox[{"D", "[", 
       RowBox[{"tau2", ",", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"tau1", ",", "x"}], "]"}], " ", "tau2"}]}]}], ")"}]}]], "Input",\

 CellChangeTimes->{{3.77300881364785*^9, 3.773008826186943*^9}, {
  3.773045949950437*^9, 3.773045965422597*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"244fbb8d-66f0-461c-9d01-fde71dfa35af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", "liszt_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Wronskian", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"maketau", "[", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"liszt", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"liszt", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "liszt", "]"}]}], "}"}]}], "]"}], ",", "x"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.443283100058921*^9, 3.4432831150569897`*^9}, {
   3.47591688717039*^9, 3.475916903881818*^9}, {3.477759775132249*^9, 
   3.4777597903576*^9}, {3.482619190237958*^9, 3.482619212698303*^9}, {
   3.490633031531579*^9, 3.4906330502495832`*^9}, {3.490633102207686*^9, 
   3.4906331643146544`*^9}, 3.490976574375814*^9, {3.769765853840201*^9, 
   3.7697659055511513`*^9}, {3.772983280627737*^9, 3.772983289750338*^9}, 
   3.7730458244664516`*^9, {3.773067144034194*^9, 3.773067159880494*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"925c45da-c331-4337-b387-bee83bf40d4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"odoapply", "[", 
    RowBox[{"ll_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Sum", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"ll", ",", "Dd", ",", "i"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"f", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{"ll", ",", "Dd"}], "]"}], ",", "Dd"}], "]"}]}], "}"}]}], 
       "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.477924730993371*^9, 3.4779247316329317`*^9}, {
  3.477924819710334*^9, 3.477924839315772*^9}, {3.477925829038826*^9, 
  3.477925835507414*^9}, {3.477926066255986*^9, 3.477926153343961*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"d7599dba-b102-4299-912c-d7d7be2d70be"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"odomult", "[", 
    RowBox[{"L_", ",", "M_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "f", ",", "rem"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"rem", "=", 
       RowBox[{"odoapply", "[", 
        RowBox[{"L", ",", 
         RowBox[{"odoapply", "[", 
          RowBox[{"M", ",", 
           RowBox[{
            RowBox[{"f", "'"}], "[", "x", "]"}]}], "]"}]}], "]"}]}], ";", 
      "\n", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Coefficient", "[", 
           RowBox[{"rem", ",", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"f", "'"}], "[", "x", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], "]"}], "]"}], " ", 
         RowBox[{"Dd", "^", "i"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{
              RowBox[{"L", "*", "M"}], ",", "Dd"}], "]"}], ",", "Dd"}], 
           "]"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"odosimp", "[", "LL_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "L", ",", "outL"}], "}"}], ",", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"L", "=", 
       RowBox[{"Collect", "[", 
        RowBox[{"LL", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"Exponent", "[", 
        RowBox[{"L", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "=", "0"}], ";", 
         RowBox[{"outL", "=", "0"}]}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"n", "+", "1"}]}], ",", 
        RowBox[{"i", "=", 
         RowBox[{"i", "+", "1"}]}], ",", 
        RowBox[{"outL", "=", 
         RowBox[{"outL", "+", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"Coefficient", "[", 
             RowBox[{"L", ",", "Dd", ",", "i"}], "]"}], "]"}], " ", 
           RowBox[{"Dd", "^", "i"}]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "outL"}], ")"}]}], "]"}]}], "\n"}], "Input",
 CellChangeTimes->{{3.444474776512616*^9, 3.444474826593281*^9}, 
   3.4446623347155333`*^9, 3.477924607749216*^9, {3.477925385047029*^9, 
   3.4779254783230953`*^9}, {3.477925515868528*^9, 3.477925574328168*^9}, {
   3.47792560457395*^9, 3.477925618186117*^9}, {3.477925708753602*^9, 
   3.477925711264248*^9}, {3.477925744995491*^9, 3.477925800167532*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"18f2ed73-25ca-42ab-92b0-047e0d1fff6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findK", "[", "vec_", "]"}], ":=", 
  RowBox[{"odosimp", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Wronskian", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{"vec", ",", 
         RowBox[{
          RowBox[{"ff", "'"}], "[", "x", "]"}]}], "]"}], ",", "x"}], "]"}], 
     "/", 
     RowBox[{"Wronskian", "[", 
      RowBox[{"vec", ",", "x"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"ff", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "i_"}], "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"Dd", "^", 
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"Wronskian", "[", 
        RowBox[{
         RowBox[{"{", "f_", "}"}], ",", "x"}], "]"}], "\[Rule]", "f"}]}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4913078816574373`*^9, 3.491307909624508*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"eef725f6-cae1-4d5f-a615-4b2b2a362b21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"KP", "[", "u_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], "/", "4"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{"u", ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"u", ",", "t"}], "]"}], "-", 
       RowBox[{
        RowBox[{"1", "/", "4"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", "*", "u", "*", 
           RowBox[{"D", "[", 
            RowBox[{"u", ",", "x"}], "]"}]}], "+", 
          RowBox[{"D", "[", 
           RowBox[{"u", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}], ")"}]}]}], ",", "x"}],
      "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"8e98905b-5987-4407-971f-0a6c6a5fae3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bilinearKP", "[", "tau_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "newtau1", ",", "newtau2", ",", "prod", ",", "x1", ",", "x2", ",", "y1", 
      ",", "y2", ",", "z1", ",", "z2"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Applying bilinear KP equation to \>\"", ",", "tau"}], 
      "]"}], ";", "\n", 
     RowBox[{"newtau1", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "-", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "-", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "-", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"newtau2", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "+", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "+", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "+", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"prod", "=", 
      RowBox[{"newtau1", "*", "newtau2"}]}], ";", "\n", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"prod", ",", 
          RowBox[{"{", 
           RowBox[{"y1", ",", "4"}], "}"}]}], "]"}], "-", 
        RowBox[{"4", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"prod", ",", "y3"}], "]"}], ",", "y1"}], "]"}]}], "+", 
        RowBox[{"3", 
         RowBox[{"D", "[", 
          RowBox[{"prod", ",", 
           RowBox[{"{", 
            RowBox[{"y2", ",", "2"}], "}"}]}], "]"}]}]}], " ", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "->", "x"}], ",", "\n", 
         RowBox[{"x2", "->", "y"}], ",", 
         RowBox[{"x3", "->", "t"}], ",", 
         RowBox[{"y1", "->", "0"}], ",", 
         RowBox[{"y2", "->", "0"}], ",", 
         RowBox[{"y3", "->", "0"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157134908945*^9, 3.414157146493334*^9}, {
   3.414157539681963*^9, 3.414157570952484*^9}, {3.4457670468487673`*^9, 
   3.445767055711692*^9}, {3.445767157028308*^9, 3.4457671684505367`*^9}, {
   3.4457673078314657`*^9, 3.445767317198688*^9}, {3.4777585974759808`*^9, 
   3.477758606524411*^9}, 
   3.477924418096677*^9},ExpressionUUID->"e2e5c0e4-8920-4d32-98d8-\
befe7bc3be0b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"z", " ", "x"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "2"}], " ", "y"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "3"}], " ", "t"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
    RowBox[{"z", "\[Rule]", "lambda"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157300430751*^9, 3.414157329903987*^9}, {
  3.41415741908654*^9, 
  3.414157442106514*^9}},ExpressionUUID->"ff9ac8a7-4ccf-4bc7-a7f6-\
fe4ffa5cacc2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newphi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"t1", " ", "z"}], " ", "+", " ", 
       RowBox[{"t2", " ", 
        RowBox[{"z", "^", "2"}]}], " ", "+", " ", 
       RowBox[{"t3", " ", 
        RowBox[{"z", "^", "3"}]}], " ", "+", " ", 
       RowBox[{"t4", " ", 
        RowBox[{"z", "^", "4"}]}], " ", "+", " ", 
       RowBox[{"t5", " ", 
        RowBox[{"z", "^", "5"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
   RowBox[{"z", "\[Rule]", "lambda"}]}]}]], "Input",
 CellChangeTimes->{{3.480889814675468*^9, 3.480889852786428*^9}, {
  3.480889914226462*^9, 
  3.480889919212367*^9}},ExpressionUUID->"16299808-9c05-4881-ab58-\
498146fbd880"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", 
   RowBox[{"i1_", ",", "i2_", ",", "i3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Wronskian", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i1", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i2", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i3", "-", "1"}]}], "]"}]}], "}"}], ",", "t1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t1", "\[Rule]", "ddt1"}], ",", 
         RowBox[{"t2", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "ddt2"}]}], ",", 
         RowBox[{"t3", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "3"}], " ", "ddt3"}]}], ",", 
         RowBox[{"t4", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "4"}], " ", "ddt4"}]}], ",", 
         RowBox[{"t5", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "5"}], " ", "ddt5"}]}]}], "}"}]}], ")"}], " ", 
     RowBox[{"ddt1", "^", "2"}], " ", 
     RowBox[{"ddt2", "^", "2"}], " ", 
     RowBox[{"ddt3", "^", "2"}], " ", 
     RowBox[{"ddt4", "^", "2"}], " ", 
     RowBox[{"ddt5", "^", "2"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "]"}], "/.", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ddt1", "^", "j1_"}], " ", 
     RowBox[{"ddt2", "^", "j2_"}], " ", 
     RowBox[{"ddt3", "^", "j3_"}], " ", 
     RowBox[{"ddt4", "^", "j4_"}], " ", 
     RowBox[{"ddt5", "^", "j5_"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{
        RowBox[{"j1", "-", "2"}], ",", 
        RowBox[{"j2", "-", "2"}], ",", 
        RowBox[{"j3", "-", "2"}], ",", 
        RowBox[{"j4", "-", "2"}], ",", 
        RowBox[{"j5", "-", "2"}]}], "]"}], "[", "tau", "]"}], "[", 
     RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.480890153129841*^9, 3.480890254473042*^9}, {
  3.4808903646072083`*^9, 3.480890368174728*^9}, {3.48089070528187*^9, 
  3.480890717031369*^9}, {3.4808908693944883`*^9, 3.480890876924096*^9}, {
  3.4808935525914373`*^9, 3.48089363566728*^9}, {3.480932393064308*^9, 
  3.480932408314354*^9}, {3.4831786439185*^9, 3.48317864406774*^9}, {
  3.4831787030762444`*^9, 
  3.4831787032663307`*^9}},ExpressionUUID->"e424e03e-37f0-4455-a5b9-\
d4963d2423e9"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chapter 1 MyAnimate and SimpleEvolver", "Section",
 CellChangeTimes->{{3.44328212785538*^9, 3.443282148452435*^9}, {
   3.471796682652899*^9, 3.4717966850387173`*^9}, {3.471796962999517*^9, 
   3.471796979124291*^9}, 
   3.874766090734005*^9},ExpressionUUID->"2462f245-132d-4900-aa77-\
6a5b7f12d306"],

Cell["\<\
This actually defines TWO commands: one for animating the graph of a function \
of x and t as a curve that evolves and one for animating a function of x, y \
and t as a surface that evolves:\
\>", "Text",
 CellChangeTimes->{{3.44328215745478*^9, 
  3.4432821876675653`*^9}},ExpressionUUID->"a2e658a2-a344-4285-8713-\
6e56b8456103"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MyAnimate", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"y0", ",", "y1"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0", ",", "t1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"MyAnimate", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0_", ",", "z1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Plot3D", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "y0", ",", "y1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"z0", ",", "z1"}], "}"}]}], ",", 
       RowBox[{"ColorFunction", "->", "\"\<Aquamarine\>\""}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0", ",", "t1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.874846401437584*^9, 
  3.8748464126493893`*^9}},ExpressionUUID->"27ed7e9a-fcea-4045-b1ef-\
5e8d173e26d3"],

Cell["\<\
This animates the APPROXIMATE dynamics of a solution to the equation u_t = \
u*(u - u_x) with a given initial profile by showing what it would look like \
tsize units of time later.  (It is more accurate for smaller values of tsize, \
and you can alter this in the definition.)    Moreover, changing the line \
that starts RHS =. .. will allow you to change it to do the same thing to any \
other equation of the form u_t = (stuff not involving t derivatives).\
\>", "Text",
 CellChangeTimes->{{3.443282229757188*^9, 3.443282345104162*^9}, {
  3.473161396806233*^9, 
  3.473161397236434*^9}},ExpressionUUID->"f78dc5c4-fee2-4ae5-b867-\
e344ff100339"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SimpleEvolver", "[", 
    RowBox[{"profile_", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "x0_", ",", " ", "x1_"}], "}"}]}], "]"}], " ", ":=",
    " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"RHS", " ", "=", " ", 
      RowBox[{"profile", " ", 
       RowBox[{"(", 
        RowBox[{"profile", " ", "-", " ", 
         RowBox[{"D", "[", 
          RowBox[{"profile", ",", " ", "x"}], "]"}]}], ")"}]}]}], ";", "\n", 
     "    ", 
     RowBox[{"numpts", " ", "=", " ", "1000"}], ";", "\n", "    ", 
     RowBox[{"tsize", " ", "=", " ", ".1"}], ";", "\n", "    ", 
     RowBox[{"profiletable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{"profile", " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"evolvedtable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"profile", " ", "+", " ", 
             RowBox[{"tsize", " ", "RHS"}]}], " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", "profiletable", "]"}], ",", " ", 
          RowBox[{"Dashing", "[", ".01", "]"}], ",", " ", 
          RowBox[{"Line", "[", "evolvedtable", "]"}]}], "}"}], "]"}], ",", 
       " ", 
       RowBox[{"Axes", " ", "->", " ", "True"}]}], "]"}]}], ")"}]}], 
  "\n"}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.483258785530251*^9, 3.483258796991585*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"45838e61-9f2b-4b46-b5f6-08bda6be3662"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 2 AnimBurgers (Burgers Equation)", "Section",
 CellChangeTimes->{{3.443282432656147*^9, 3.443282438629882*^9}, {
  3.471796782212636*^9, 3.471796782992079*^9}, {3.4717970453659563`*^9, 
  3.471797060533765*^9}},ExpressionUUID->"d4be86f3-072b-4714-892e-\
23ca8850e703"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimBurgers", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "a_", ",", "b_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"liszt", ",", "i", ",", "j", ",", "n", ",", "min", ",", "max"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"liszt", "[", "0", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"N", "[", 
           RowBox[{"f", "/.", 
            RowBox[{"x", "\[Rule]", "i"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"a", "-", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{"b", "+", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"min", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"max", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "100"}], ",", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{
        RowBox[{"liszt", "[", "i", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"liszt", "[", 
               RowBox[{"i", "-", "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], "+", 
             RowBox[{".1", " ", 
              RowBox[{
               RowBox[{"liszt", "[", 
                RowBox[{"i", "-", "1"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "2"}], "]"}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"liszt", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"liszt", "[", "0", "]"}], "]"}]}], "}"}]}], "]"}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ListAnimate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"Line", "[", 
              RowBox[{"liszt", "[", "i", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"a", ",", "b"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"min", "-", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}], ",", 
               RowBox[{"max", "+", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}]}], "}"}]}], 
            "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "99", ",", "1"}], "}"}]}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",ExpressionUUID->"a269d82d-6c35-4a7f-a5a2-\
5b98e8167a92"],

Cell["\<\
The command above takes a function of x (and only x) and a range of x values \
as its argument.  It then illustrates the dynamics of a solution with that \
initial profile under the evolution induced by the IVB equation by moving \
each point to the right at a speed proportional to its height.  \
(Unfortunately, we cannot write a closed formula for this in most situations, \
and it often stops being the graph of a function after a short amount of \
time.)\
\>", "Text",
 CellChangeTimes->{{3.44328249827944*^9, 3.443282577347246*^9}, 
   3.86265595937878*^9},ExpressionUUID->"780076c6-3394-4590-a24f-\
5af40bf6e60e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimBurgers", "[", 
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{".5", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"x", "^", "2"}]}], ")"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.443282486107095*^9, 
  3.4432824891439238`*^9}},ExpressionUUID->"35d5af76-c3eb-44ab-86c0-\
22f82c5769ed"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Chapter 3 usol and u2sol (general 1-solution solution and a particular \
2-soliton solution to KdV)\
\>", "Section",
 CellChangeTimes->{{3.443282821419016*^9, 3.443282827597438*^9}, {
   3.443283033979579*^9, 3.443283034875185*^9}, {3.4432835333432293`*^9, 
   3.443283543286147*^9}, {3.443283643996009*^9, 3.443283648971768*^9}, {
   3.4717970664869213`*^9, 3.47179707887897*^9}, {3.473161387958055*^9, 
   3.473161389579623*^9}, {3.874847417823151*^9, 3.874847429631769*^9}, 
   3.874847624294959*^9},ExpressionUUID->"f569f65a-cc31-48f8-9a75-\
5f03b7a4b057"],

Cell["\<\
As part of a homework problem, you are supposed to write a command which \
takes in a function of x and t and outputs the number zero if it is a \
solution.  I am putting a definition here just as a placeholder for this \
command:\
\>", "Text",
 CellChangeTimes->{{3.4741903112138653`*^9, 
  3.4741903493805933`*^9}},ExpressionUUID->"08879a3a-bfd1-4dec-8923-\
707814ec9da3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KdV", "[", "v_", "]"}], ":=", 
   RowBox[{
   "Print", "[", 
    "\"\<You are supposed to create your own KdV[] command.  Please write \
one. -Alex\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.474190350998053*^9, 
  3.474190403385339*^9}},ExpressionUUID->"05b4a278-1f4e-4f0c-9c95-\
73f00f7d9fc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"usol", "[", 
   RowBox[{"x_", ",", "t_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"8", 
   RowBox[{
    RowBox[{"k", "^", "2"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"k", " ", "x"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}], "+", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "k"}], " ", "x"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}]}], ")"}], "^", 
     "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.408982782904517*^9, 3.408982800142632*^9}, {
  3.443282835828529*^9, 
  3.4432828367058268`*^9}},ExpressionUUID->"58971509-f0d5-41a6-bc85-\
d735623d3389"],

Cell["\<\
The formula above solves the KdV equation for every value of k.  It is a \
solution that looks like a bell of height 2k^2 travelling to the left with \
speed k^2, as these two examples illustrate:\
\>", "Text",
 CellChangeTimes->{{3.44328288654286*^9, 
  3.4432829292675447`*^9}},ExpressionUUID->"a3c7a39c-4797-45dd-900c-\
c0edbbfb4ed7"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"usol", "[", 
    RowBox[{"x", ",", "t", ",", "1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.443282841390106*^9, 
  3.443282862328362*^9}},ExpressionUUID->"3441e4fe-b249-4f73-a6f1-\
b1f0c93e0ecc"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"usol", "[", 
    RowBox[{"x", ",", "t", ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.443282841390106*^9, 
  3.443282875632957*^9}},ExpressionUUID->"2c4037ae-2792-4e7f-9383-\
d033f90b8da3"],

Cell["\<\
Here is a formula for a 2-soliton solution in which we see peaks that look \
very much like the two illustrated above, but now they appear TOGETHER in a \
solution...and it is NOT just a sum of the previous two solutions!\
\>", "Text",
 CellChangeTimes->{{3.443282962853112*^9, 
  3.4432829983863277`*^9}},ExpressionUUID->"0411a853-5c51-457e-abac-\
d4a86729905e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2sol", "[", 
   RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"24", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", "x"}], ")"}]}]], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"20", " ", "t"}], "+", 
         RowBox[{"8", " ", "x"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"34", " ", "t"}], "+", 
        RowBox[{"10", " ", "x"}]}]]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}]}], ")"}], 
    "2"]]}]], "Input",
 CellChangeTimes->{{3.443283003726342*^9, 
  3.443283016366675*^9}},ExpressionUUID->"19720267-7989-4c3c-8567-\
8265a945239c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 4 Elliptic Solutions to KdV: uell", "Section",
 CellChangeTimes->{{3.443282704382225*^9, 3.4432827092329597`*^9}, {
  3.443283638280884*^9, 3.443283639627708*^9}, {3.4717970839188013`*^9, 
  3.4717970963585176`*^9}},ExpressionUUID->"47a31417-6517-4928-b806-\
038e81ee0253"],

Cell["\<\
Plotting the Weierstrass p-function corresponding to the parameters 28 and \
-24:\
\>", "Text",
 CellChangeTimes->{{3.874767122928001*^9, 
  3.874767156370577*^9}},ExpressionUUID->"2001f66c-5189-442d-bcd1-\
18e24f7af045"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"WeierstrassP", "[", 
    RowBox[{"x", ",", 
     RowBox[{"{", 
      RowBox[{"28", ",", 
       RowBox[{"-", "24"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.874767025894208*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"1307b1af-ae60-42b9-ba7a-9558e18a8600"],

Cell["It is periodic with periods equal to TWICE these numbers:", "Text",
 CellChangeTimes->{{3.87476713422607*^9, 
  3.8747671732541122`*^9}},ExpressionUUID->"ac787c38-f1e9-4b0f-87ae-\
3a397607247e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"WeierstrassHalfPeriods", "[", 
   RowBox[{"{", 
    RowBox[{"28", ",", 
     RowBox[{"-", "24"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.874767075646599*^9},
 CellLabel->"In[19]:=",ExpressionUUID->"1be9d295-15af-48fc-b0d9-bc0b1f4dab16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.7422062367111931`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"1.0094529099892116`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.874767076893849*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"70cbfd95-3e30-4f14-a599-3f9960b38d64"]
}, Open  ]],

Cell["\<\
To check, I am plotting the function together with another copy shifted \
horizontally by twice that real period:\
\>", "Text",
 CellChangeTimes->{{3.874767175875175*^9, 
  3.87476721043406*^9}},ExpressionUUID->"4faf4d1f-b58a-4b66-b192-\
0afa93e2f874"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"WeierstrassP", "[", 
      RowBox[{
       RowBox[{"x", "+", "2.0189"}], ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         RowBox[{"-", "24"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"WeierstrassP", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         RowBox[{"-", "24"}]}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", ".1", ",", "2.02"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", ".2", ",", ".8"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", ".2", ",", ".7"}], "]"}]}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8747670959908657`*^9, 3.874767108148918*^9}, {
  3.874767233968557*^9, 3.874767263603467*^9}, {3.874767478320812*^9, 
  3.874767506528551*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"35004d9a-b752-4e83-bbf4-f471fa068422"],

Cell[TextData[{
 "If we try the same thing with the period that is a complex number, we must \
specify that we want only the real part of the output value since otherwise \
slight numerical errors will prevent it from being plotted in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.874767367833477*^9, 
  3.874767434872806*^9}},ExpressionUUID->"77194004-621e-4ddc-af3c-\
af3faec6b799"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"WeierstrassP", "[", 
       RowBox[{
        RowBox[{"x", "+", 
         RowBox[{"2", "*", 
          RowBox[{"-", "0.7422062"}], " ", "I"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"28", ",", 
          RowBox[{"-", "24"}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"WeierstrassP", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         RowBox[{"-", "24"}]}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", ".1", ",", "2.02"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", ".2", ",", ".8"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", ".2", ",", ".7"}], "]"}]}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.874767324520051*^9, 3.87476733677148*^9}, {
  3.874767511882782*^9, 3.8747675124993896`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"9dd67e19-7f1d-41a0-895d-01a08815943c"],

Cell["\<\
Since a half-period of 1.5 should mean the function has period 3, we expect \
these parameters to produce a function with period 3:\
\>", "Text",
 CellChangeTimes->{{3.8747678951697893`*^9, 
  3.874767922178393*^9}},ExpressionUUID->"c156bf81-0064-417c-9c32-\
e1f549d971d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeierstrassInvariants", "[", 
  RowBox[{"{", 
   RowBox[{"I", ",", "1.5"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.874767929614053*^9},
 CellLabel->"In[31]:=",ExpressionUUID->"ac1f84d4-cfc7-41b1-884e-3645491efc2b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8.27475580084227`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4.269365011353792`"}], "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8747679305611753`*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"d2562d40-1247-4607-94c8-860eff1e4f0b"]
}, Open  ]],

Cell["That is visually confirmed by this plot:", "Text",
 CellChangeTimes->{{3.8747679516245623`*^9, 
  3.8747679842617693`*^9}},ExpressionUUID->"34743b5e-cdc9-4ef2-bb9c-\
fb58ac7967f5"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"WeierstrassP", "[", 
    RowBox[{"x", ",", 
     RowBox[{"{", 
      RowBox[{"8.27476", ",", 
       RowBox[{"-", "4.26937"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.874767940597953*^9, 3.874767946952239*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"80a94111-6a14-4d5e-b782-54179dd6524d"],

Cell["", "Text",
 CellChangeTimes->{{3.8747681293307743`*^9, 
  3.874768133340412*^9}},ExpressionUUID->"77e9e94d-b316-4a2b-9a60-\
ccb57c3a2ea1"],

Cell["Because it satisfies a differential equation, this function", "Text",
 CellChangeTimes->{{3.874768159886167*^9, 
  3.874768192933659*^9}},ExpressionUUID->"cae6c145-cd5b-42b4-9a1c-\
8dfe89b9d324"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", "z_", "]"}], ":=", 
  RowBox[{"WeierstrassP", "[", 
   RowBox[{"z", ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "18"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.874768141537115*^9, 3.874768153694622*^9}, {
  3.874768361023374*^9, 3.874768361090159*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"e46926d9-59c6-4405-9acb-10667df5da35"],

Cell["\<\
should give the value zero when substituted into the expression:\
\>", "Text",
 CellChangeTimes->{{3.874768163870337*^9, 
  3.874768209062748*^9}},ExpressionUUID->"1afc01de-dcc0-48fa-8358-\
1b9f1df9b289"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"w", "'"}], "[", "z", "]"}], "^", "2"}], "-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", 
     RowBox[{
      RowBox[{"w", "[", "z", "]"}], "^", "3"}]}], "-", 
    RowBox[{"12", 
     RowBox[{"w", "[", "z", "]"}]}], "-", "18"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8747682149488363`*^9, 3.87476822819241*^9}, {
  3.874768406044653*^9, 3.874768409149543*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"9e493f74-cc17-408a-bba7-6f33658644e8"],

Cell[BoxData[
 RowBox[{"18", "+", 
  RowBox[{"12", " ", 
   RowBox[{"WeierstrassP", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "18"}], "}"}]}], "]"}]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox[
    RowBox[{"WeierstrassP", "[", 
     RowBox[{"z", ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "18"}], "}"}]}], "]"}], "3"]}], "+", 
  SuperscriptBox[
   RowBox[{"WeierstrassPPrime", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "18"}], "}"}]}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.8747682287023697`*^9, 3.8747683647330017`*^9, 
  3.874768409611144*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"834da46c-caa3-4714-9286-a77a4371f340"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.874768229946282*^9, 3.874768232278335*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"676daf9a-3bfd-4ebf-8e0c-c800a0281d10"],

Cell[BoxData[
 RowBox[{"18", "+", 
  RowBox[{"12", " ", 
   RowBox[{"WeierstrassP", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "18"}], "}"}]}], "]"}]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox[
    RowBox[{"WeierstrassP", "[", 
     RowBox[{"z", ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "18"}], "}"}]}], "]"}], "3"]}], "+", 
  SuperscriptBox[
   RowBox[{"WeierstrassPPrime", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "18"}], "}"}]}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.874768232678966*^9, 3.87476836658282*^9, 
  3.8747684117991047`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"e079e611-3741-4908-be48-6098c680065f"]
}, Open  ]],

Cell["\<\
However, Mathematica does not seem to recognize it.  Still, we can see some \
evidence that it is true by simply plotting the values of this expression \
over an interval:\
\>", "Text",
 CellChangeTimes->{{3.874768235242105*^9, 3.874768242528927*^9}, {
  3.874768477368526*^9, 
  3.874768514560567*^9}},ExpressionUUID->"65b362d0-c028-48c0-8a88-\
3b10ed10b609"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"w", "'"}], "[", "z", "]"}], "^", "2"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{
        RowBox[{"w", "[", "z", "]"}], "^", "3"}]}], "-", 
      RowBox[{"12", 
       RowBox[{"w", "[", "z", "]"}]}], "-", "18"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", ".05", ",", "1.2"}], "}"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", ".01"}], ",", ".01"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"AbsoluteThickness", "[", "6", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8747682447437363`*^9, 3.874768324192102*^9}, {
  3.874768417983696*^9, 3.874768421302351*^9}, {3.87476845957797*^9, 
  3.874768468061061*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"ae71127c-6f76-4e19-b366-c6fd2e502dd0"],

Cell["\<\
For any values of the constant parameters c, omega, k1 and k2 this is a \
solution to the KdV equation made out of the Weirstrass p-function for the \
curve with parameters k1 and k2.\
\>", "Text",
 CellChangeTimes->{{3.443282716776655*^9, 
  3.4432827484633017`*^9}},ExpressionUUID->"9c7d0a9c-e51a-4c55-874a-\
36c61120516a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uell", "[", 
   RowBox[{
   "x_", ",", "t_", ",", "c_", ",", "omega_", ",", "k1_", ",", "k2_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"WeierstrassP", "[", 
     RowBox[{
      RowBox[{"x", "+", 
       RowBox[{"c", " ", "t"}], "+", "omega"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "k2"}], "}"}]}], "]"}]}], "+", 
   RowBox[{"2", 
    RowBox[{"c", "/", "3"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.443549062363452*^9, {3.8747690092603188`*^9, 3.874769011778088*^9}, {
   3.874769409007949*^9, 3.874769414013115*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"452d7b86-7699-40e7-bca8-093f3dd0ad7f"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"uell", "[", 
    RowBox[{"x", ",", "t", ",", "3", ",", "0", ",", "2", ",", "4"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{3.8747686201200953`*^9},
 CellLabel->"In[66]:=",ExpressionUUID->"bc33048d-02e3-4168-9c93-9e389d84302f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"x_", ",", "t_", ",", "gamma2_"}], "]"}], ":=", 
  RowBox[{"Re", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"WeierstrassP", "[", 
      RowBox[{
       RowBox[{"x", " ", "+", " ", "t", " ", "+", " ", "I"}], ",", "\n", 
       "              ", 
       RowBox[{"WeierstrassInvariants", "[", 
        RowBox[{"{", 
         RowBox[{"I", ",", "gamma2"}], "}"}], "]"}]}], " ", "]"}]}], " ", "+",
     " ", 
    RowBox[{"2", "/", "3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.87476864610224*^9, 3.874768646104465*^9}, {
  3.874768969224865*^9, 3.874768972555888*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"b7409f8a-faf8-4ebb-9519-ede3356bc685"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", " ", "t", ",", " ", "1"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", " ", "5"}], "]"}]], "Input",\

 CellChangeTimes->{{3.87476865945907*^9, 3.874768659461499*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"3c697f80-caca-4f71-be7e-bcef1ef675fa"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "t", ",", "3"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.8747686962859*^9, 3.87476870695363*^9}, {
  3.874769036089024*^9, 3.874769039101328*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"ef8ad124-65e8-45fd-98ac-7bfd4c20d632"],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"usol", "[", 
      RowBox[{"x", ",", "t", ",", "1"}], "]"}], ",", 
     RowBox[{"uell", "[", 
      RowBox[{"x", ",", "t", ",", "1", ",", 
       RowBox[{"I", " ", 
        RowBox[{"Pi", "/", "2"}]}], ",", 
       RowBox[{"4", "/", "3"}], ",", 
       RowBox[{
        RowBox[{"-", "8"}], "/", "27"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.874769049840378*^9, 3.8747690996211567`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"aaf3b60e-b0ff-446a-a79f-0b75106a8bb4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 5 KdV n-solitons: maketau and makeu", "Section",
 CellChangeTimes->{{3.4432830873957872`*^9, 3.443283091831626*^9}, {
  3.4717970906461487`*^9, 3.471797093766285*^9}, {3.8678363520054693`*^9, 
  3.867836356581293*^9}},ExpressionUUID->"aa99fce7-63c3-4464-84ae-\
4e2c3aa63fe0"],

Cell["\<\
This command just turns a function into 2 times its second logarithmic \
derivative:\
\>", "Text",
 CellChangeTimes->{{3.443283331946959*^9, 
  3.443283344354203*^9}},ExpressionUUID->"6025d6f3-2b8b-4a99-96e3-\
ccb7342cd3cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeu", "[", "tau_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", "tau", " ", 
      RowBox[{"D", "[", 
       RowBox[{"tau", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], "-", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"tau", ",", "x"}], "]"}], "^", "2"}]}]}], ")"}], "/", 
   RowBox[{"tau", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{
  3.4432833269944077`*^9, {3.770389024776661*^9, 3.770389058857048*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"8a99caec-f9ac-4c5d-803b-a1d636bff072"],

Cell["\<\
If tau[x,t] is a function which turns into a solution of KdV when you apply \
makeu, then we call it \"a tau-function of the KdV equation\".  As it turns \
out, it is often easier to write the tau-function than the solution.  For \
example, the solution -2/x^2 that we have encountered before comes from tau=x:\
\>", "Text",
 CellChangeTimes->{{3.443283348834179*^9, 
  3.443283427152458*^9}},ExpressionUUID->"6d180c02-f2e4-459f-8a11-\
e03ef06c78e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.443283428451769*^9, 3.443283430370734*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"f6eed1be-715f-44fb-b2c2-4b1d287d249d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["2", 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{3.4432834312681217`*^9, 3.445679566372615*^9, 
  3.475858878370949*^9, 3.478614052826974*^9, 3.769765944974522*^9, 
  3.770389066430585*^9, 3.7732376333842297`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"56038c76-82db-4614-b547-3870450aade4"]
}, Open  ]],

Cell["\<\
Since n-soliton tau-functions are made out of 1-soliton tau-functions, we \
start by teaching Mathematica how to make the tau-function when there is only \
one pair of numbers selected:\
\>", "Text",
 CellChangeTimes->{{3.773045832652876*^9, 
  3.773045871719368*^9}},ExpressionUUID->"60968746-b200-4f24-8204-\
31a7717b547c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"c_", ",", "k_"}], "}"}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "+", 
     RowBox[{
      RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}], "+", 
   RowBox[{"c", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "x"}], "-", 
      RowBox[{
       RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}]}]}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"010cff67-0958-4436-8541-649b247a6340"],

Cell["\<\
Applying makeu to the output of this generates a 1-soliton solution:\
\>", "Text",
 CellChangeTimes->{{3.773045888273752*^9, 
  3.773045897684136*^9}},ExpressionUUID->"6dc4e302-61bf-4753-abed-\
45c196f255fd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maketau", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.7730459003045597`*^9, 3.77304590708447*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"5a21f881-01cd-4b21-8e95-97b6110d4536"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "t"}], "-", 
    RowBox[{"2", " ", "x"}]}]], "+", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"8", " ", "t"}], "+", 
    RowBox[{"2", " ", "x"}]}]]}]], "Output",
 CellChangeTimes->{3.773045909403904*^9, 3.773237633427794*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"1c1c5404-942d-473a-ad57-457c73f71b4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.7730459100180483`*^9, 3.773045914045063*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"e92c7a41-f315-4fdf-a4ab-530d1f2987f5"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "t"}], "-", 
          RowBox[{"2", " ", "x"}]}]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"8", " ", "t"}], "+", 
          RowBox[{"2", " ", "x"}]}]]}]}], ")"}], "2"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "t"}], "-", 
        RowBox[{"2", " ", "x"}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"8", " ", "t"}], "+", 
        RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", "t"}], "-", 
         RowBox[{"2", " ", "x"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"8", " ", "t"}], "+", 
         RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "t"}], "-", 
       RowBox[{"2", " ", "x"}]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"8", " ", "t"}], "+", 
       RowBox[{"2", " ", "x"}]}]]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.7730459144963083`*^9, 3.7732376334402227`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"1a696847-5ab7-4c1c-a21f-fcfadc95333b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KdV", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.7730459152499933`*^9, 3.773045917350452*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"a7353906-8fe2-46aa-b62b-d5228ce88b6b"],

Cell[BoxData[
 RowBox[{"KdV", "[", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "t"}], "-", 
           RowBox[{"2", " ", "x"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"8", " ", "t"}], "+", 
           RowBox[{"2", " ", "x"}]}]]}]}], ")"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", "t"}], "-", 
         RowBox[{"2", " ", "x"}]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"8", " ", "t"}], "+", 
         RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "t"}], "-", 
          RowBox[{"2", " ", "x"}]}]]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"8", " ", "t"}], "+", 
          RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "t"}], "-", 
        RowBox[{"2", " ", "x"}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"8", " ", "t"}], "+", 
        RowBox[{"2", " ", "x"}]}]]}], ")"}], "2"]], "]"}]], "Output",
 CellChangeTimes->{3.773045917919346*^9, 3.773237633477113*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"a0d081e7-15e0-4a8e-b40b-f6654ee0688e"]
}, Open  ]],

Cell["\<\
We can extend this to a command that makes a 2-soliton tau-function as \
follows:\
\>", "Text",
 CellChangeTimes->{{3.772983168693852*^9, 3.772983203671544*^9}, {
  3.773008790298916*^9, 3.773008810443783*^9}, {3.773045878385483*^9, 
  3.773045878908085*^9}, {3.773045924417399*^9, 
  3.773045943452613*^9}},ExpressionUUID->"13f85530-63e1-4d94-8263-\
df61623bf08d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c1_", ",", "k1_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c2_", ",", "k2_"}], "}"}]}], "}"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"tau1", "=", 
     RowBox[{"maketau", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c1", ",", "k1"}], "}"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tau2", "=", 
     RowBox[{"maketau", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c2", ",", "k2"}], "}"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tau1", " ", 
      RowBox[{"D", "[", 
       RowBox[{"tau2", ",", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"tau1", ",", "x"}], "]"}], " ", "tau2"}]}]}], ")"}]}]], "Input",\

 CellChangeTimes->{{3.77300881364785*^9, 3.773008826186943*^9}, {
  3.773045949950437*^9, 3.773045965422597*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"36fa3f0d-bc6b-4fa4-a46f-8b4ba331ea29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", 
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.773008830066317*^9, 3.773008843485635*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"b811db2e-0b8e-438d-b69e-0f0cec2ad838"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", "t"}], "-", 
               RowBox[{"2", " ", "x"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"8", " ", "t"}], "+", 
               RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "27"}], " ", "t"}], "-", 
            RowBox[{"3", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"27", " ", "t"}], "+", 
            RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "t"}], "-", 
            RowBox[{"2", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"8", " ", "t"}], "+", 
            RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "-", 
          RowBox[{"8", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "27"}], " ", "t"}], "-", 
            RowBox[{"3", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"27", " ", "t"}], "+", 
            RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "t"}], "-", 
            RowBox[{"2", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"8", " ", "t"}], "+", 
            RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "27"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]]}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "t"}], "-", 
            RowBox[{"2", " ", "x"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"8", " ", "t"}], "+", 
            RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "27"}], " ", "t"}], "-", 
          RowBox[{"3", " ", "x"}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"27", " ", "t"}], "+", 
          RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "t"}], "-", 
          RowBox[{"2", " ", "x"}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"8", " ", "t"}], "+", 
          RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "27"}], " ", "t"}], "-", 
           RowBox[{"3", " ", "x"}]}]]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"27", " ", "t"}], "+", 
           RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}]], "Output",\

 CellChangeTimes->{3.773008845800213*^9, 3.77304597406161*^9, 
  3.773237633525525*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"07310c2d-a7fc-4238-8756-995814b264be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KdV", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.773008846881641*^9, 3.773008848310581*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"fe0a9fdd-2867-459a-8619-036f42f24105"],

Cell[BoxData[
 RowBox[{"KdV", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "8"}], " ", "t"}], "-", 
                RowBox[{"2", " ", "x"}]}]]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"8", " ", "t"}], "+", 
                RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "27"}], " ", "t"}], "-", 
               RowBox[{"3", " ", "x"}]}]]}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"27", " ", "t"}], "+", 
               RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}], "+", 
     
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", "t"}], "-", 
               RowBox[{"2", " ", "x"}]}]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"8", " ", "t"}], "+", 
               RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "-", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "27"}], " ", "t"}], "-", 
             RowBox[{"3", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"27", " ", "t"}], "+", 
             RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "27"}], " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "27"}], " ", "t"}], "-", 
              RowBox[{"3", " ", "x"}]}]]}], "+", 
           RowBox[{"27", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"27", " ", "t"}], "+", 
              RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
   "/", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "27"}], " ", "t"}], "-", 
           RowBox[{"3", " ", "x"}]}]], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"27", " ", "t"}], "+", 
           RowBox[{"3", " ", "x"}]}]]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "t"}], "-", 
           RowBox[{"2", " ", "x"}]}]], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"8", " ", "t"}], "+", 
           RowBox[{"2", " ", "x"}]}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "27"}], " ", "t"}], "-", 
            RowBox[{"3", " ", "x"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"27", " ", "t"}], "+", 
            RowBox[{"3", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.773008848868088*^9, 3.7730459826838408`*^9, 
  3.773237633541601*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"f155b3fd-20d7-44b5-b369-f9aed78e3ab9"]
}, Open  ]],

Cell["\<\
But, to produce an n-soliton solution we need to be a bit more sophisticated. \
 The argument of this command is a list of all of the number pairs called \
\[OpenCurlyDoubleQuote]list\[CloseCurlyDoubleQuote] and then it uses the \
notation \[OpenCurlyDoubleQuote]list[[i,j]]\[CloseCurlyDoubleQuote] to pull \
out the j-th component of the i-th pair:\
\>", "Text",
 CellChangeTimes->{{3.772983216659438*^9, 
  3.772983277234344*^9}},ExpressionUUID->"444b3bdf-54d5-4b22-8b29-\
7c2e1fb70183"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maketau", "[", "liszt_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Wronskian", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"maketau", "[", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"liszt", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"liszt", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "liszt", "]"}]}], "}"}]}], "]"}], ",", "x"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.443283100058921*^9, 3.4432831150569897`*^9}, {
   3.47591688717039*^9, 3.475916903881818*^9}, {3.477759775132249*^9, 
   3.4777597903576*^9}, {3.482619190237958*^9, 3.482619212698303*^9}, {
   3.490633031531579*^9, 3.4906330502495832`*^9}, {3.490633102207686*^9, 
   3.4906331643146544`*^9}, 3.490976574375814*^9, {3.769765853840201*^9, 
   3.7697659055511513`*^9}, {3.772983280627737*^9, 3.772983289750338*^9}, 
   3.7730458244664516`*^9, {3.773067144034194*^9, 3.773067159880494*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"48bda7f2-f66d-4763-8cfd-5e5604198b4f"],

Cell["\<\
The command above takes a list of the form { {c1,k1}, {c2,k2}, \
{c3,k3},....,{cn,kn} } and turns it into a tau-function for a KdV solution \
(or, if you do not choose the numbers wisely, into the number zero).  The \
resulting solution will have n different things moving to the left (either \
solitary wave peaks such as those Russell observed or vertical asymptotes \
that go to negative infinity).  The parameters k1,..,kn determine the SPEEDS \
of those objects (they will have speeds k1^2, k2^2, ..., kn^2) and the \
c1,...,cn parameters will control both the positions and whether they are \
smooth soliton peaks or \"singularities' with vertical asymptotes.

For example:\
\>", "Text",
 CellChangeTimes->{{3.443283119545885*^9, 3.443283290979474*^9}, {
  3.7729833105236483`*^9, 
  3.772983339377706*^9}},ExpressionUUID->"07180984-a8dc-49b1-aa7d-\
d24d6cabdd22"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", 
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.443283293369103*^9, 3.44328329606015*^9}, 
   3.443283467330964*^9, {3.4909766033123627`*^9, 3.490976607304132*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"c318a3ae-75d1-459e-858a-bdc61f95a047"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "t"}], "-", "x"}]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "+", "x"}]]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "t"}], "-", "x"}]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "t"}], "-", 
              RowBox[{"2", " ", "x"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"8", " ", "t"}], "+", 
              RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "t"}], "-", "x"}]]}], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", "+", "x"}]]}], ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "t"}], "-", 
            RowBox[{"2", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"8", " ", "t"}], "+", 
            RowBox[{"2", " ", "x"}]}]]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], "-", "x"}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], "-", "x"}]], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "t"}], "-", 
            RowBox[{"2", " ", "x"}]}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"8", " ", "t"}], "+", 
            RowBox[{"2", " ", "x"}]}]]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "t"}], "-", "x"}]]}], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], "-", "x"}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "t"}], "-", "x"}]]}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], "-", "x"}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "t"}], "-", 
             RowBox[{"2", " ", "x"}]}]]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"8", " ", "t"}], "+", 
             RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], "-", "x"}]]}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "+", "x"}]]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "t"}], "-", 
          RowBox[{"2", " ", "x"}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"8", " ", "t"}], "+", 
          RowBox[{"2", " ", "x"}]}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "t"}], "-", "x"}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "+", "x"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", "t"}], "-", 
           RowBox[{"2", " ", "x"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"8", " ", "t"}], "+", 
           RowBox[{"2", " ", "x"}]}]]}]}], ")"}]}]}], ")"}], "2"]}]], "Output",\

 CellChangeTimes->{
  3.443283468815792*^9, 3.445679566562972*^9, 3.475858878573163*^9, 
   3.4759169111026917`*^9, 3.478614053742278*^9, {3.490976581074572*^9, 
   3.4909766078808117`*^9}, 3.769765955322392*^9, 3.7730671562849894`*^9, 
   3.773237633591421*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"f8553e38-9f1a-4fba-8659-b1311b1fa9f3"]
}, Open  ]],

Cell["\<\
is the solution shown in the book as part of example 5.9.  It has one smooth \
peak and one vertical asymptote.  However, changing c2 from 1 to -1 makes it \
into the non-singular 2-soliton solution that we saw back in Section 3.9.\
\>", "Text",
 CellChangeTimes->{{3.443283471666088*^9, 3.44328355422202*^9}, {
  3.769765969453393*^9, 3.769765971363752*^9}, {3.867836222878912*^9, 
  3.867836225844501*^9}, {3.8678362846616488`*^9, 
  3.867836286398472*^9}},ExpressionUUID->"7cd90176-9519-40d7-82d0-\
d026c5624afc"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 6 Differential Operators", "Section",
 CellChangeTimes->{{3.443281885096765*^9, 3.443281895217861*^9}, {
  3.4432835967278423`*^9, 3.443283597580654*^9}, {3.443283653235672*^9, 
  3.443283654843585*^9}, {3.47179709971105*^9, 3.471797100774846*^9}, {
  3.4758578719964943`*^9, 
  3.475857874995687*^9}},ExpressionUUID->"906e0329-2e5b-4de9-8093-\
b93ea60d2f08"],

Cell[CellGroupData[{

Cell["applying differential operators", "Subsection",
 CellChangeTimes->{{3.477924616401555*^9, 
  3.4779246267770967`*^9}},ExpressionUUID->"ffce737d-6a20-489b-88b9-\
deb3ff16789e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"odoapply", "[", 
    RowBox[{"ll_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Sum", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"ll", ",", "Dd", ",", "i"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"f", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{"ll", ",", "Dd"}], "]"}], ",", "Dd"}], "]"}]}], "}"}]}], 
       "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.477924730993371*^9, 3.4779247316329317`*^9}, {
  3.477924819710334*^9, 3.477924839315772*^9}, {3.477925829038826*^9, 
  3.477925835507414*^9}, {3.477926066255986*^9, 3.477926153343961*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"24266fd7-76fd-4c11-8ec8-30f19da0a085"],

Cell["\<\
Type the differential operator L as a polynomial in Dd with coefficients that \
are functions of x.  Then it can be applied to the function f using \
odoapply[L,f]\
\>", "Text",
 CellChangeTimes->{{3.477924644185833*^9, 
  3.477924684530148*^9}},ExpressionUUID->"a06e8795-8ce2-4ed9-85d0-\
9364b1ed8c72"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LL", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "2"}], "-", 
   RowBox[{"2", "/", 
    RowBox[{"x", "^", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.477924686045735*^9, 3.47792469470188*^9}, 
   3.48224520224751*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"676ea30d-147f-4ab5-bb44-69d780f7715d"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "-", 
  FractionBox["2", 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{
  3.47792469524708*^9, 3.477924736022382*^9, 3.4779248431129103`*^9, 
   3.477925852811648*^9, {3.477926145137363*^9, 3.4779261555693502`*^9}, 
   3.478614049863529*^9, 3.480936612827733*^9, 3.490976420207967*^9, 
   3.7732377129148197`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"fbc9f559-9546-4de5-a458-f0cea8519e57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"LL", ",", 
   RowBox[{"x", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"2", "x"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.477924695879726*^9, 3.4779247007572308`*^9}, {
   3.477924754498118*^9, 3.4779247618881073`*^9}, 3.482245206334032*^9},
 CellLabel->"In[19]:=",ExpressionUUID->"173ec342-a6da-4be5-9ac6-89bef7d810dd"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", " ", "x"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], "x"]], "Output",
 CellChangeTimes->{
  3.477924701849172*^9, {3.477924737741125*^9, 3.477924762407648*^9}, 
   3.477924844748481*^9, 3.477925853993876*^9, {3.4779261476378937`*^9, 
   3.477926156550865*^9}, 3.478614049912702*^9, 3.480936613166065*^9, 
   3.4909764202652683`*^9, 3.773237712946725*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"b42b095c-d009-4ce0-bb1b-7ef6d066f086"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiplying Differential Operators", "Subsection",
 CellChangeTimes->{{3.444474784148168*^9, 3.444474788592413*^9}, {
  3.471797120425852*^9, 3.471797122342896*^9}, {3.47585786358983*^9, 
  3.4758578777270203`*^9}},ExpressionUUID->"56be3213-6911-40b2-933f-\
2920b17fe612"],

Cell["Execute these definitions:", "Text",
 CellChangeTimes->{{3.444474835379912*^9, 
  3.444474842924233*^9}},ExpressionUUID->"1fc85f3f-ec2f-45d4-be6c-\
e003880fbed1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"odomult", "[", 
    RowBox[{"L_", ",", "M_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "f", ",", "rem"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"rem", "=", 
       RowBox[{"odoapply", "[", 
        RowBox[{"L", ",", 
         RowBox[{"odoapply", "[", 
          RowBox[{"M", ",", 
           RowBox[{
            RowBox[{"f", "'"}], "[", "x", "]"}]}], "]"}]}], "]"}]}], ";", 
      "\n", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Coefficient", "[", 
           RowBox[{"rem", ",", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"f", "'"}], "[", "x", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], "]"}], "]"}], " ", 
         RowBox[{"Dd", "^", "i"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{
              RowBox[{"L", "*", "M"}], ",", "Dd"}], "]"}], ",", "Dd"}], 
           "]"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"odosimp", "[", "LL_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "L", ",", "outL"}], "}"}], ",", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"L", "=", 
       RowBox[{"Collect", "[", 
        RowBox[{"LL", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"Exponent", "[", 
        RowBox[{"L", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "=", "0"}], ";", 
         RowBox[{"outL", "=", "0"}]}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"n", "+", "1"}]}], ",", 
        RowBox[{"i", "=", 
         RowBox[{"i", "+", "1"}]}], ",", 
        RowBox[{"outL", "=", 
         RowBox[{"outL", "+", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"Coefficient", "[", 
             RowBox[{"L", ",", "Dd", ",", "i"}], "]"}], "]"}], " ", 
           RowBox[{"Dd", "^", "i"}]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "outL"}], ")"}]}], "]"}]}], "\n"}], "Input",
 CellChangeTimes->{{3.444474776512616*^9, 3.444474826593281*^9}, 
   3.4446623347155333`*^9, 3.477924607749216*^9, {3.477925385047029*^9, 
   3.4779254783230953`*^9}, {3.477925515868528*^9, 3.477925574328168*^9}, {
   3.47792560457395*^9, 3.477925618186117*^9}, {3.477925708753602*^9, 
   3.477925711264248*^9}, {3.477925744995491*^9, 3.477925800167532*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"25882765-c576-4d1b-b71d-d2b1eecc55f6"],

Cell["\<\
Now you can define differential operators using \"Dd\" for \"partial\":\
\>", "Text",
 CellChangeTimes->{{3.4444748535662193`*^9, 
  3.4444748747824306`*^9}},ExpressionUUID->"59f412e7-6027-4871-b3ef-\
ef4402873403"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LL", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "2"}], "+", 
   RowBox[{"Sin", "[", "x", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"MM", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "3"}], "-", 
   RowBox[{"x", " ", "Dd"}], " ", "+", " ", 
   RowBox[{"Exp", "[", "x", "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.4444748761534*^9, 3.444474891373898*^9}, {
  3.482245213214335*^9, 3.482245215942458*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"8448a587-9eed-4604-b16f-5c23142d590f"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "+", 
  RowBox[{"Sin", "[", "x", "]"}]}]], "Output",
 CellChangeTimes->{3.4444748926387053`*^9, 3.444643720361161*^9, 
  3.445679566844252*^9, 3.477817602166058*^9, 3.4779256228132057`*^9, 
  3.4779258706417313`*^9, 3.477926188264448*^9, 3.4786140499952602`*^9, 
  3.4809366141913767`*^9, 3.490976420326352*^9, 3.7732377129896584`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"9477bdc2-e249-4cc0-837d-56debf546ae2"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "3"], "+", 
  SuperscriptBox["\[ExponentialE]", "x"], "-", 
  RowBox[{"Dd", " ", "x"}]}]], "Output",
 CellChangeTimes->{3.4444748926387053`*^9, 3.444643720361161*^9, 
  3.445679566844252*^9, 3.477817602166058*^9, 3.4779256228132057`*^9, 
  3.4779258706417313`*^9, 3.477926188264448*^9, 3.4786140499952602`*^9, 
  3.4809366141913767`*^9, 3.490976420326352*^9, 3.773237712990237*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"996632a9-72ae-4a15-8c9e-8fb95e23451a"]
}, Open  ]],

Cell["and you can compute their products with \"odomult[ , ]\":", "Text",
 CellChangeTimes->{{3.444474897386294*^9, 
  3.44447491202551*^9}},ExpressionUUID->"7a61c819-38d8-411f-a01f-\
61a8f6d07152"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odomult", "[", 
  RowBox[{"LL", ",", "MM"}], "]"}]], "Input",
 CellChangeTimes->{{3.482245220205862*^9, 3.482245221357339*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"191ae4ce-3716-47e1-8b83-5fa0d823c39b"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "5"], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "x"}], "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "-", 
     RowBox[{"x", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.477925637983947*^9, 3.477925717409028*^9, 
  3.4779258078349667`*^9, 3.4779258731116877`*^9, 3.4779261923620777`*^9, 
  3.4786140501499434`*^9, 3.480936615221259*^9, 3.4909764204406233`*^9, 
  3.773237713073968*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"967e75dd-67b4-4e21-a6b3-499131164897"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odomult", "[", 
  RowBox[{"MM", ",", "LL"}], "]"}]], "Input",
 CellChangeTimes->{{3.444474917656485*^9, 3.444474920723687*^9}, {
  3.482245224445612*^9, 3.4822452259894857`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"61455e6e-d291-4f49-a5ce-676259d3a416"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "5"], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "-", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", "x"}], ")"}], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "x"}], "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.444474921803941*^9, 3.4446437299238997`*^9, 
  3.4456795672022467`*^9, 3.477817602659267*^9, 3.47792588722046*^9, 
  3.4779261952769957`*^9, 3.478614050387436*^9, 3.4809366161711597`*^9, 
  3.4909764205879717`*^9, 3.773237713178178*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"2501db3a-cf2f-4623-8fd9-73aa65921de5"]
}, Open  ]],

Cell["Then, of course, their commutator is ", "Text",
 CellChangeTimes->{{3.444474923581192*^9, 
  3.444474927385318*^9}},ExpressionUUID->"1a76d72d-b422-4a50-bf9e-\
9a158d5f8ae5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"comm", "=", 
  RowBox[{
   RowBox[{"odomult", "[", 
    RowBox[{"LL", ",", "MM"}], "]"}], "-", 
   RowBox[{"odomult", "[", 
    RowBox[{"MM", ",", "LL"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.444474929551526*^9, 3.444474951447485*^9}, {
  3.482245229518696*^9, 3.4822452338056927`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"5bc5f79c-de4a-4932-bf6d-14d1dd4114e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", "x"}], ")"}], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "-", 
     RowBox[{"x", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.444474940039806*^9, 3.444474952698388*^9}, 
   3.4446437362106247`*^9, 3.4456795673599863`*^9, 3.477817602850683*^9, 
   3.477925891665084*^9, 3.477926199775503*^9, 3.4786140506954527`*^9, 
   3.480936616621389*^9, 3.490976420772573*^9, 3.773237713305414*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"220f271d-c03d-4c2f-be89-7b3efc8cd45a"]
}, Open  ]],

Cell["\<\
But, notice that this is not written in a nice form (there is more than one \
Dd^2 term!) and so you can simplify it with \"odosimp[]\":\
\>", "Text",
 CellChangeTimes->{{3.444474955815383*^9, 
  3.444474974684368*^9}},ExpressionUUID->"689ddc0b-cc38-418a-849b-\
d98d96e9ccd5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odosimp", "[", "comm", "]"}]], "Input",
 CellChangeTimes->{{3.444474975853547*^9, 3.444474979453277*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"1d1c4f59-3723-4f3a-a018-9d5ae08d6344"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "x"], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.4444749801376762`*^9, 3.444643743610635*^9, 
  3.4456795675261097`*^9, 3.477817603029772*^9, 3.47792590205833*^9, 
  3.4779262026629047`*^9, 3.478614050746347*^9, 3.480936617751141*^9, 
  3.4909764208275843`*^9, 3.7732377133356447`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"22ceee3d-bd31-4890-8297-c9d1a08e08f4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["making a differential operator with specified kernel", "Subsection",
 CellChangeTimes->{{3.4779246321296864`*^9, 
  3.477924637865555*^9}},ExpressionUUID->"e76651a5-81ef-4c4c-b5b8-\
97c8b2147ba5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findK", "[", "vec_", "]"}], ":=", 
  RowBox[{"odosimp", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Wronskian", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{"vec", ",", 
         RowBox[{
          RowBox[{"ff", "'"}], "[", "x", "]"}]}], "]"}], ",", "x"}], "]"}], 
     "/", 
     RowBox[{"Wronskian", "[", 
      RowBox[{"vec", ",", "x"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"ff", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "i_"}], "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"Dd", "^", 
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"Wronskian", "[", 
        RowBox[{
         RowBox[{"{", "f_", "}"}], ",", "x"}], "]"}], "\[Rule]", "f"}]}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4913078816574373`*^9, 3.491307909624508*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"c44cb01e-42c3-44c4-9da3-a8588868c9b9"],

Cell["\<\
The command above takes a list of functions of x as an argument and gives you \
back the lowest order monic differential operator which has all of them in \
its kernel.  For instance:\
\>", "Text",
 CellChangeTimes->{{3.443281901237433*^9, 3.443281928594616*^9}, {
  3.443281965616746*^9, 
  3.443281966760571*^9}},ExpressionUUID->"d80f6f1d-2f63-410b-b31e-\
388a05c3679a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"K", "=", 
  RowBox[{"findK", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"E", "^", "x"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44328193038426*^9, 3.4432819372993593`*^9}, {
  3.443281980075144*^9, 3.443281981642398*^9}, {3.4779253336882763`*^9, 
  3.477925334165452*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"1f8b5888-6012-4063-aebf-67eac56d7d38"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "+", 
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}]], "-", 
  FractionBox[
   RowBox[{"Dd", " ", "x"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}]]}]], "Output",
 CellChangeTimes->{
  3.4432819379664583`*^9, 3.44328198212838*^9, {3.4446439501514482`*^9, 
   3.4446439782879267`*^9}, 3.4446440122972116`*^9, 3.445679566634707*^9, 
   3.477817601913015*^9, {3.477924964830309*^9, 3.477924977559762*^9}, 
   3.4779250901594067`*^9, {3.477925139965361*^9, 3.477925162853797*^9}, {
   3.477925223254801*^9, 3.4779252358575487`*^9}, {3.477925299625949*^9, 
   3.477925334845455*^9}, 3.477925861152144*^9, 3.477926171071967*^9, 
   3.477926309070146*^9, 3.478614051033511*^9, 3.480936618714072*^9, 
   3.490976420986855*^9, 3.773237713382299*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"614dca45-9e9b-42f5-b962-59ff6e2fdeef"]
}, Open  ]],

Cell["\<\
This means that d^2 -x/(x-1) d + 1/(x-1) is a differential operator that \
gives zero when applied to x or to E^x.  We can check this as follows:\
\>", "Text",
 CellChangeTimes->{{3.443281942635178*^9, 
  3.4432819927357817`*^9}},ExpressionUUID->"47a705ee-b254-4345-9c65-\
80118d5a297c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"K", ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.443281996401932*^9, 3.443282021362648*^9}, {
  3.4432820533738422`*^9, 3.443282054665678*^9}, {3.477925338473609*^9, 
  3.477925343389269*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"3351d2cb-212e-4565-91a6-9f2b9a68d35d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.443282023226446*^9, 3.4432820552670927`*^9, 
  3.445679566675528*^9, 3.477817601958742*^9, 3.477925344095747*^9, 
  3.477925863776291*^9, 3.47792617290136*^9, 3.4779263119874353`*^9, 
  3.478614051080494*^9, 3.4809366191187677`*^9, 3.490976421016623*^9, 
  3.7732377134164133`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"b72c877d-7ba5-4595-86d0-3aa3095cd27d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"K", ",", 
   RowBox[{"Exp", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.443282030469554*^9, 3.443282060049877*^9}, {
  3.4779253473556843`*^9, 3.477925351110957*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"be1068a0-efab-4400-bcec-3490f8e8b3ea"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.443282039964026*^9, 3.443282060601932*^9}, 
   3.445679566712105*^9, 3.477817602009164*^9, 3.477925351840745*^9, 
   3.477925864908877*^9, 3.47792617516605*^9, 3.477926313320218*^9, 
   3.4786140511293077`*^9, 3.480936619869413*^9, 3.490976421049509*^9, 
   3.773237713427112*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"40ab1274-3be3-49c4-b3e0-7e811f2932a0"]
}, Open  ]],

Cell["Aha, it worked!", "Text",
 CellChangeTimes->{{3.443282072538954*^9, 
  3.443282075215414*^9}},ExpressionUUID->"04568aa1-c807-4a70-b0c9-\
7c45f2ec0aca"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 10: KP", "Section",
 CellChangeTimes->{{3.445679588377763*^9, 3.445679592008327*^9}, {
  3.445692161453845*^9, 3.4456921617672243`*^9}, {3.445768660593342*^9, 
  3.4457686609214067`*^9}},ExpressionUUID->"6959b01e-6495-4a4b-a443-\
608a188ecbc0"],

Cell["\<\
This tests to see if u is a solution to the KP equation, returning \"0\" if \
it is:\
\>", "Text",
 CellChangeTimes->{{3.445767190257915*^9, 
  3.445767203040662*^9}},ExpressionUUID->"3e5c4871-31a0-4ba9-adf8-\
6ca332024cc4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"KP", "[", "u_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], "/", "4"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{"u", ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"u", ",", "t"}], "]"}], "-", 
       RowBox[{
        RowBox[{"1", "/", "4"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", "*", "u", "*", 
           RowBox[{"D", "[", 
            RowBox[{"u", ",", "x"}], "]"}]}], "+", 
          RowBox[{"D", "[", 
           RowBox[{"u", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}], ")"}]}]}], ",", "x"}],
      "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"7eec68e7-47a0-4d4f-984f-60c11c176e3a"],

Cell["\<\
This tests to see if tau is a solution to the bilinear KP equation, returning \
\"0\" if it is :\
\>", "Text",
 CellChangeTimes->{{3.445767205439644*^9, 
  3.445767221364169*^9}},ExpressionUUID->"10c23b7f-268f-4f92-9155-\
29dd57a01a3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bilinearKP", "[", "tau_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "newtau1", ",", "newtau2", ",", "prod", ",", "x1", ",", "x2", ",", "y1", 
      ",", "y2", ",", "z1", ",", "z2"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Applying bilinear KP equation to \>\"", ",", "tau"}], 
      "]"}], ";", "\n", 
     RowBox[{"newtau1", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "-", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "-", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "-", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"newtau2", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "+", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "+", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "+", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"prod", "=", 
      RowBox[{"newtau1", "*", "newtau2"}]}], ";", "\n", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"prod", ",", 
          RowBox[{"{", 
           RowBox[{"y1", ",", "4"}], "}"}]}], "]"}], "-", 
        RowBox[{"4", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"prod", ",", "y3"}], "]"}], ",", "y1"}], "]"}]}], "+", 
        RowBox[{"3", 
         RowBox[{"D", "[", 
          RowBox[{"prod", ",", 
           RowBox[{"{", 
            RowBox[{"y2", ",", "2"}], "}"}]}], "]"}]}]}], " ", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "->", "x"}], ",", "\n", 
         RowBox[{"x2", "->", "y"}], ",", 
         RowBox[{"x3", "->", "t"}], ",", 
         RowBox[{"y1", "->", "0"}], ",", 
         RowBox[{"y2", "->", "0"}], ",", 
         RowBox[{"y3", "->", "0"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157134908945*^9, 3.414157146493334*^9}, {
   3.414157539681963*^9, 3.414157570952484*^9}, {3.4457670468487673`*^9, 
   3.445767055711692*^9}, {3.445767157028308*^9, 3.4457671684505367`*^9}, {
   3.4457673078314657`*^9, 3.445767317198688*^9}, {3.4777585974759808`*^9, 
   3.477758606524411*^9}, 
   3.477924418096677*^9},ExpressionUUID->"8301f7de-0f62-40d7-991c-\
536bc96f8fec"],

Cell["\<\
The command phi[lambda,n] makes a nicely weighted function by differentiating \
Exp[xz+yz^2+tz^3] n times with respect to z and evaluating it at z=lambda:\
\>", "Text",
 CellChangeTimes->{{3.445767229641271*^9, 
  3.445767261610092*^9}},ExpressionUUID->"a0ef2d73-35c5-4092-b8ff-\
49ce8ba4ab78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"z", " ", "x"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "2"}], " ", "y"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "3"}], " ", "t"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
    RowBox[{"z", "\[Rule]", "lambda"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157300430751*^9, 3.414157329903987*^9}, {
  3.41415741908654*^9, 
  3.414157442106514*^9}},ExpressionUUID->"46911b0e-35a2-44d4-91cd-\
10e4be9d2ba8"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Chapter 11: Gamma_24 and the Geometric Origins of Bilinear KP\
\>", "Section",
 CellChangeTimes->{{3.478957560389926*^9, 3.478957569907987*^9}, {
  3.4790254793984613`*^9, 3.479025485244006*^9}, {3.480889651323081*^9, 
  3.480889652043229*^9}},ExpressionUUID->"2307b480-ae8e-4ba7-938f-\
055e809ddbd0"],

Cell[CellGroupData[{

Cell["\<\
Could the Bilinear KP Equation be an algebraic equation \"in disguise\"?\
\>", "Subsection",
 CellChangeTimes->{{3.479023915526041*^9, 3.4790239421811743`*^9}, {
  3.4822453012280483`*^9, 
  3.4822453066581306`*^9}},ExpressionUUID->"9780adfe-5289-4b91-977b-\
554addd2c749"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Omega", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Wronskian", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"phi", "[", 
        RowBox[{"0", ",", 
         RowBox[{"i", "-", "1"}]}], "]"}], ",", 
       RowBox[{"phi", "[", 
        RowBox[{"0", ",", 
         RowBox[{"j", "-", "1"}]}], "]"}]}], "}"}], ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"gentau", "=", 
  RowBox[{
   RowBox[{"c12", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], "+", 
   RowBox[{"c13", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "3"}], "]"}]}], "+", " ", 
   RowBox[{"c14", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "4"}], "]"}]}], "+", 
   RowBox[{"c23", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}], "+", " ", 
   RowBox[{"c24", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"2", ",", "4"}], "]"}]}], "+", " ", 
   RowBox[{"c34", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"3", ",", "4"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.479024292396372*^9, 
  3.479024334633787*^9}},ExpressionUUID->"08b40045-34f0-4db9-be5d-\
958e771d1140"],

Cell[BoxData[
 RowBox[{"c12", "+", 
  RowBox[{"2", " ", "c13", " ", "x"}], "+", 
  RowBox[{"c24", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "t"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
  RowBox[{"c23", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
  RowBox[{"3", " ", "c14", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
  RowBox[{"c34", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", "t", " ", "x"}], "+", 
     SuperscriptBox["x", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["y", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.479024322860708*^9},ExpressionUUID->"3410fd99-7f24-4141-9884-\
be2831bb7cab"]
}, Open  ]],

Cell["\<\
When we plug the linear combination gentau into Bilinear KP we see the \
equation for a Grassmann Cone:\
\>", "Text",
 CellChangeTimes->{{3.479024325721566*^9, 
  3.4790243717132597`*^9}},ExpressionUUID->"619b9efa-32ee-46a5-a06d-\
7ea96af7564a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bilinearKP", "[", "gentau", "]"}]], "Input",
 CellChangeTimes->{{3.4790243732139387`*^9, 
  3.479024377197227*^9}},ExpressionUUID->"c945d4e5-daa7-462c-a482-\
15a9f3e26062"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Applying bilinear KP equation to \"\>", "\[InvisibleSpace]", 
   RowBox[{"c12", "+", 
    RowBox[{"2", " ", "c13", " ", "x"}], "+", 
    RowBox[{"c24", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "6"}], " ", "t"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
    RowBox[{"c23", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"3", " ", "c14", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"c34", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", "t", " ", "x"}], "+", 
       SuperscriptBox["x", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}]}]}],
  SequenceForm[
  "Applying bilinear KP equation to ", $CellContext`c12 + (
     2 $CellContext`c13) $CellContext`x + $CellContext`c24 ((-6) \
$CellContext`t + 2 $CellContext`x^3) + $CellContext`c23 ($CellContext`x^2 - 
     2 $CellContext`y) + (3 $CellContext`c14) ($CellContext`x^2 + 
     2 $CellContext`y) + $CellContext`c34 (((-12) $CellContext`t) \
$CellContext`x + $CellContext`x^4 + 12 $CellContext`y^2)],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4790243777661037`*^9},ExpressionUUID->"887349bf-52c4-41e5-9d81-\
a246f36f02cf"],

Cell[BoxData[
 RowBox[{"288", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"c14", " ", "c23"}], "-", 
    RowBox[{"c13", " ", "c24"}], "+", 
    RowBox[{"c12", " ", "c34"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.479024377814373*^9},ExpressionUUID->"fa8f0363-5b58-4cad-ab22-\
b4be1b5d0c40"]
}, Open  ]],

Cell["\<\
Can we isolate the coefficients of gentau using derivatives?  Yes, if we make \
differential operators out of the polynomials Omega[i,j] themselves:\
\>", "Text",
 CellChangeTimes->{{3.479024385834835*^9, 
  3.479024416321136*^9}},ExpressionUUID->"595da33d-9ff1-426f-ba9c-\
16a7236eaf59"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"P", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Omega", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "ddx"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "ddy"}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "3"}], " ", "ddt"}]}]}], "}"}]}]}], "\n", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.478957600151366*^9, 3.478957605829257*^9}, 
   3.478957782480482*^9, 3.479024287581407*^9, 3.4790244246184883`*^9, 
   3.479025323854292*^9},ExpressionUUID->"51c1d3a9-49eb-4360-94e8-\
79684b792bac"],

Cell["If you apply the differential operator:", "Text",
 CellChangeTimes->{{3.479024221343172*^9, 3.479024241212826*^9}, {
  3.47902427603307*^9, 3.4790242775335293`*^9}, {3.4790244328823023`*^9, 
  3.479024448137795*^9}, {3.479024481579006*^9, 
  3.479024484730932*^9}},ExpressionUUID->"d1962a12-b432-48b7-a397-\
219d73ae383e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "[", 
  RowBox[{"2", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.479024450457358*^9, 
  3.479024451624709*^9}},ExpressionUUID->"f52efe5c-3c43-48c2-bd4c-\
fc926f94d5e2"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ddx", "2"], "-", "ddy"}]], "Output",
 CellChangeTimes->{
  3.479024452123065*^9},ExpressionUUID->"f7e5c9bc-5cae-48b8-9591-\
57186501a4c4"]
}, Open  ]],

Cell["to gentau and then set (x,y,t)=(0,0,0) you get", "Text",
 CellChangeTimes->{{3.479024456052516*^9, 
  3.479024496387068*^9}},ExpressionUUID->"cb97c5ca-deab-4d1a-a14b-\
68df882b2a57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"gentau", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2"}], "}"}]}], "]"}], "-", 
   RowBox[{"D", "[", 
    RowBox[{"gentau", ",", "y"}], "]"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0"}], ",", 
    RowBox[{"y", "\[Rule]", "0"}], ",", 
    RowBox[{"t", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.479025160295576*^9, 3.4790251816006927`*^9}, {
  3.479025226695304*^9, 
  3.479025227347754*^9}},ExpressionUUID->"d163919f-227b-4434-94da-\
b6582b19203c"],

Cell[BoxData[
 RowBox[{"4", " ", "c23"}]], "Output",
 CellChangeTimes->{3.479025182794153*^9, 
  3.479025228846003*^9},ExpressionUUID->"8d0d1c3a-ee0c-439e-8a07-\
7c75ba2558db"]
}, Open  ]],

Cell["\<\
This isolates the coefficient c23 by applying P[2,3]!  Can we get c24 the \
same way?\
\>", "Text",
 CellChangeTimes->{{3.4790252459445467`*^9, 
  3.479025267038344*^9}},ExpressionUUID->"b544c459-bc64-4483-8c14-\
178007f9ced3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "[", 
  RowBox[{"2", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.479025272219893*^9, 
  3.479025273846054*^9}},ExpressionUUID->"f4c6f92c-3885-43ef-979a-\
ef17d5e1d6e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "ddt"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["ddx", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.479025274870278*^9},ExpressionUUID->"ea5ee878-a245-4940-b744-\
0a3a6dd26b60"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{"gentau", ",", "t"}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"D", "[", 
     RowBox[{"gentau", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0"}], ",", 
    RowBox[{"y", "\[Rule]", "0"}], ",", 
    RowBox[{"t", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.479025281902566*^9, 
  3.479025303524034*^9}},ExpressionUUID->"18862b46-2711-4c27-a527-\
58ee1326ca31"],

Cell[BoxData[
 RowBox[{"36", " ", "c24"}]], "Output",
 CellChangeTimes->{
  3.4790253048846397`*^9},ExpressionUUID->"3161169a-8386-4382-be7c-\
d7dfe510ae56"]
}, Open  ]],

Cell["\<\
Yes!

We can define  a command that will give us these differential expressions \
that isolate the coefficients\
\>", "Text",
 CellChangeTimes->{{3.479025307321755*^9, 
  3.479025372112855*^9}},ExpressionUUID->"b4ca8460-4543-45c3-a78d-\
3e781f33722d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"i", ",", "j"}], "]"}], " ", 
     RowBox[{"ddx", "^", "2"}], " ", 
     RowBox[{"ddy", "^", "2"}], " ", 
     RowBox[{"ddt", "^", "2"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"ddx", "^", "ii_"}], " ", 
     RowBox[{"ddy", "^", "jj_"}], " ", 
     RowBox[{"ddt", "^", "kk_"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{
        RowBox[{"ii", "-", "2"}], ",", 
        RowBox[{"jj", "-", "2"}], ",", 
        RowBox[{"kk", "-", "2"}]}], "]"}], "[", "tau", "]"}], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}]}]], "Input",ExpressionUUID->\
"609ca425-9ee1-4b8b-bd88-1525de05e86d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"2", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957819250658*^9, 
  3.4789578205005417`*^9}},ExpressionUUID->"03e64c73-a1e8-4c8f-b34d-\
edbd62b73f69"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["tau", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"2", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4789578209207497`*^9, 
  3.479025377927226*^9},ExpressionUUID->"6eb103e2-ea27-471c-850c-\
b4272024f11e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957769971393*^9, 
  3.478957770759941*^9}},ExpressionUUID->"d0fcfede-d6bc-477a-953e-\
1f883a3b08e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["tau", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"4", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4789577712601852`*^9, 3.478957809066749*^9}, 
   3.4790253798433123`*^9},ExpressionUUID->"5be23a0f-905f-4020-b24e-\
b9a6ce046736"]
}, Open  ]],

Cell["\<\
And we substitute those into the Plucker Relation (just as we substituted \
D[f/2,{x,2}], D[f/6,{y,3}],... into the equation for the sphere)\
\>", "Text",
 CellChangeTimes->{{3.479025382283551*^9, 
  3.47902543896247*^9}},ExpressionUUID->"779ee1d2-483a-4cc5-bd79-\
4b4919dc368c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plucker", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "4"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "4"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "4"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.478957880095435*^9, 3.478957905261107*^9}, {
  3.478957955854273*^9, 
  3.478957956738791*^9}},ExpressionUUID->"032a56b2-17b8-451d-bf0b-\
f7790c3f27db"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"4", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.478957905913319*^9, 3.4789579574764347`*^9, 
  3.479025441521751*^9},ExpressionUUID->"9287dddd-e3bc-44fa-8bbd-\
11af948a8a82"]
}, Open  ]],

Cell["COULD THIS BE BILINEAR KP?!?", "Text",
 CellChangeTimes->{{3.4790254459248953`*^9, 
  3.4790254540185966`*^9}},ExpressionUUID->"60f8443f-f062-42b4-8ed6-\
bdf5571bf245"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bilinkp", "=", 
  RowBox[{"bilinearKP", "[", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478957959438107*^9, 
  3.478957980439797*^9}},ExpressionUUID->"197fafcf-ba27-4fc7-8167-\
c4ee53531c7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Applying bilinear KP equation to \"\>", "\[InvisibleSpace]", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}],
  SequenceForm["Applying bilinear KP equation to ", 
   $CellContext`tau[$CellContext`x, $CellContext`y, $CellContext`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.478957981301383*^9, 
  3.479025457388544*^9},ExpressionUUID->"90ec19a3-b89b-49af-a563-\
75eb4a71f119"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["tau", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}], "2"]}], "+", 
  RowBox[{"8", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["tau", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}], "2"]}], "-", 
  RowBox[{"8", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"4", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.478957981345232*^9, 
  3.479025457448593*^9},ExpressionUUID->"3165a080-3245-4979-bfc2-\
1a5fda1ea5ee"]
}, Open  ]],

Cell["Yes, they differ just be an overall factor of 2:", "Text",
 CellChangeTimes->{{3.4790254459248953`*^9, 3.4790254540185966`*^9}, {
  3.874847520120349*^9, 
  3.8748475287970753`*^9}},ExpressionUUID->"b80b965f-7c45-493b-b23c-\
64b5fcc1b7c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"2", "plucker"}], "-", "bilinkp"}], "]"}]], "Input",
 CellChangeTimes->{{3.478958179069852*^9, 
  3.478958183456942*^9}},ExpressionUUID->"b515690f-bd71-4165-8938-\
ed0b58b1bf67"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4789581840684967`*^9, 
  3.4790254604023046`*^9},ExpressionUUID->"b25cafe2-cca5-4dc2-a3ae-\
f354bc1e7aa5"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 12: Gamma_kn and the Bilinear KP Hierarchy", "Section",
 CellChangeTimes->{{3.478957560389926*^9, 3.478957569907987*^9}, {
  3.4790254793984613`*^9, 3.479025485244006*^9}, {3.48088962576777*^9, 
  3.480889654796876*^9}, {3.8664706126847982`*^9, 
  3.866470613579596*^9}},ExpressionUUID->"13b0b56a-c59f-47c1-b46a-\
a65b84636537"],

Cell[CellGroupData[{

Cell["Making Bilinear PDEs from Plucker Relations with k=3 and n=6", \
"Subsection",
 CellChangeTimes->{{3.479023915526041*^9, 3.4790239421811743`*^9}, {
  3.480889679161359*^9, 
  3.480889720285761*^9}},ExpressionUUID->"94dd1e0d-c60e-45e8-8ea9-\
7d33a789ccb4"],

Cell["\<\
Since n=6, we will need FIVE variables.  We make a new definition for \"phi\" \
(the nicely weighted functions) that will work:\
\>", "Text",
 CellChangeTimes->{{3.480889788832213*^9, 
  3.480889812763612*^9}},ExpressionUUID->"92bb98e4-4e7c-4aea-9b8f-\
5814b5a57f1c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newphi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"t1", " ", "z"}], " ", "+", " ", 
       RowBox[{"t2", " ", 
        RowBox[{"z", "^", "2"}]}], " ", "+", " ", 
       RowBox[{"t3", " ", 
        RowBox[{"z", "^", "3"}]}], " ", "+", " ", 
       RowBox[{"t4", " ", 
        RowBox[{"z", "^", "4"}]}], " ", "+", " ", 
       RowBox[{"t5", " ", 
        RowBox[{"z", "^", "5"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
   RowBox[{"z", "\[Rule]", "lambda"}]}]}]], "Input",
 CellChangeTimes->{{3.480889814675468*^9, 3.480889852786428*^9}, {
  3.480889914226462*^9, 
  3.480889919212367*^9}},ExpressionUUID->"dfcc65c9-701b-4d34-8dee-\
9d0c666460d5"],

Cell["\<\
The command below applies the operator P[i1,i2,i3] to the arbitrary function \
tau[t1,t2,t3,t4,t5]:\
\>", "Text",
 CellChangeTimes->{{3.479025307321755*^9, 3.479025372112855*^9}, {
  3.48089011538062*^9, 
  3.480890150780601*^9}},ExpressionUUID->"2f464097-85d6-4131-a964-\
6ba506844b62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", 
   RowBox[{"i1_", ",", "i2_", ",", "i3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Wronskian", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i1", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i2", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i3", "-", "1"}]}], "]"}]}], "}"}], ",", "t1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t1", "\[Rule]", "ddt1"}], ",", 
         RowBox[{"t2", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "ddt2"}]}], ",", 
         RowBox[{"t3", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "3"}], " ", "ddt3"}]}], ",", 
         RowBox[{"t4", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "4"}], " ", "ddt4"}]}], ",", 
         RowBox[{"t5", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "5"}], " ", "ddt5"}]}]}], "}"}]}], ")"}], " ", 
     RowBox[{"ddt1", "^", "2"}], " ", 
     RowBox[{"ddt2", "^", "2"}], " ", 
     RowBox[{"ddt3", "^", "2"}], " ", 
     RowBox[{"ddt4", "^", "2"}], " ", 
     RowBox[{"ddt5", "^", "2"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "]"}], "/.", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ddt1", "^", "j1_"}], " ", 
     RowBox[{"ddt2", "^", "j2_"}], " ", 
     RowBox[{"ddt3", "^", "j3_"}], " ", 
     RowBox[{"ddt4", "^", "j4_"}], " ", 
     RowBox[{"ddt5", "^", "j5_"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{
        RowBox[{"j1", "-", "2"}], ",", 
        RowBox[{"j2", "-", "2"}], ",", 
        RowBox[{"j3", "-", "2"}], ",", 
        RowBox[{"j4", "-", "2"}], ",", 
        RowBox[{"j5", "-", "2"}]}], "]"}], "[", "tau", "]"}], "[", 
     RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.480890153129841*^9, 3.480890254473042*^9}, {
  3.4808903646072083`*^9, 3.480890368174728*^9}, {3.48089070528187*^9, 
  3.480890717031369*^9}, {3.4808908693944883`*^9, 3.480890876924096*^9}, {
  3.4808935525914373`*^9, 3.48089363566728*^9}, {3.480932393064308*^9, 
  3.480932408314354*^9}, {3.4831786439185*^9, 3.48317864406774*^9}, {
  3.4831787030762444`*^9, 
  3.4831787032663307`*^9}},ExpressionUUID->"2e670d66-3423-405f-aca4-\
404584b0eb7a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"2", ",", "3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957819250658*^9, 3.4789578205005417`*^9}, {
  3.4808902751318073`*^9, 3.480890275828148*^9}, {3.48089351248279*^9, 
  3.48089351346633*^9}},ExpressionUUID->"9b5112cd-6c20-4938-a91a-\
94181f419f04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], "-", 
  
  RowBox[{"6", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], "+", 
  
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.4789578209207497`*^9, 3.479025377927226*^9, 3.480890276547874*^9, 
   3.480890370767049*^9, 3.480890671848064*^9, 3.480890708911212*^9, 
   3.4808908793797073`*^9, 3.4808935183761883`*^9, 3.480893560678153*^9, {
   3.480893591210997*^9, 3.4808936145841627`*^9}, 3.480893646469705*^9, 
   3.4831786730464*^9, 
   3.483178705562519*^9},ExpressionUUID->"a606576a-9b12-4690-a27f-\
9c37372e5483"]
}, Open  ]],

Cell["\<\
Now we substitute those into the two (of many) Plucker relations we found for \
Gamma_36:\
\>", "Text",
 CellChangeTimes->{{3.479025382283551*^9, 3.47902543896247*^9}, {
  3.480890896763679*^9, 
  3.480890914098184*^9}},ExpressionUUID->"f9cf0498-56c4-49f5-84fa-\
ca6029a993a2"],

Cell[BoxData[
 RowBox[{"longplucker", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}]}], 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "5", ",", "6"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "4"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "5", ",", "6"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "5"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "6"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "6"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "5"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478957880095435*^9, 3.478957905261107*^9}, {
   3.478957955854273*^9, 3.478957956738791*^9}, {3.480890968312624*^9, 
   3.480891038346841*^9}, {3.4808910693637743`*^9, 3.480891079815074*^9}, 
   3.4808916811598177`*^9, 
   3.480932780250244*^9},ExpressionUUID->"6b221e5d-7176-480b-865a-\
d96bbc65ef80"],

Cell[BoxData[
 RowBox[{"shortplucker", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}]}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "5"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2", ",", "4"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3", ",", "5"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2", ",", "5"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3", ",", "4"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480891104729432*^9, 3.4808911271987143`*^9}, 
   3.480891688247321*^9, 
   3.480891776621009*^9},ExpressionUUID->"b9b91a0a-1a41-4267-9fe3-\
7d19e1d72cd8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["producing solutions as Wronskian determinants", "Subsection",
 CellChangeTimes->{{3.480936585797607*^9, 
  3.480936593273181*^9}},ExpressionUUID->"043c70f7-3b32-412c-8dee-\
618223bee49a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trytau", "=", 
  RowBox[{"Wronskian", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"newphi", "[", 
        RowBox[{"1", ",", "0"}], "]"}], "+", 
       RowBox[{"newphi", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "]"}]}], ",", 
      RowBox[{"newphi", "[", 
       RowBox[{"0", ",", "5"}], "]"}], ",", 
      RowBox[{
       RowBox[{"newphi", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "+", 
       RowBox[{"newphi", "[", 
        RowBox[{"1", ",", "0"}], "]"}]}]}], "}"}], ",", "t1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480933323153994*^9, 
  3.480933389360365*^9}},ExpressionUUID->"4ef38287-c7a5-49fe-af3c-\
ee8a7358933e"],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"t2", "+", "t4"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t2", "+", "t4"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "5"], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["t1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
       RowBox[{"60", " ", 
        SuperscriptBox["t1", "2"], " ", "t3"}], "+", 
       RowBox[{"60", " ", "t1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
          RowBox[{"2", " ", "t4"}]}], ")"}]}], "+", 
       RowBox[{"120", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3"}], "+", "t5"}],
          ")"}]}]}], ")"}]}], "-", 
    RowBox[{"5", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
       RowBox[{"24", " ", "t1", " ", "t3"}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["t2", "2"], "+", 
          RowBox[{"2", " ", "t4"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Cosh", "[", 
      RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}], "+", 
    RowBox[{"20", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "3"], "+", 
       RowBox[{"6", " ", "t1", " ", "t2"}], "+", 
       RowBox[{"6", " ", "t3"}]}], ")"}], " ", 
     RowBox[{"Sinh", "[", 
      RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.480933398317713*^9},ExpressionUUID->"5e188b4a-86c7-4160-8f7d-\
8d059e72fcb3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tau", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t2", "+", "t4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t2", "+", "t4"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "5"], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["t1", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
        RowBox[{"60", " ", 
         SuperscriptBox["t1", "2"], " ", "t3"}], "+", 
        RowBox[{"60", " ", "t1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
           RowBox[{"2", " ", "t4"}]}], ")"}]}], "+", 
        RowBox[{"120", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3"}], "+", 
           "t5"}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"5", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "4"], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
        RowBox[{"24", " ", "t1", " ", "t3"}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["t2", "2"], "+", 
           RowBox[{"2", " ", "t4"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}], "+", 
     RowBox[{"20", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "3"], "+", 
        RowBox[{"6", " ", "t1", " ", "t2"}], "+", 
        RowBox[{"6", " ", "t3"}]}], ")"}], " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.4809334161452*^9, 
  3.480933439559031*^9}},ExpressionUUID->"82606764-0bba-4259-9ef4-\
c9627ebbc135"],

Cell[CellGroupData[{

Cell[BoxData["longplucker"], "Input",
 CellChangeTimes->{{3.480933442876646*^9, 
  3.480933447910912*^9}},ExpressionUUID->"d3b821ef-b67b-49de-9b8c-\
f5233228e113"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   PanelBox[GridBox[{
      {
       StyleBox[
        StyleBox[
         DynamicBox[ToBoxes[
           FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
           StandardForm],
          ImageSizeCache->{286., {2., 8.}}],
         StripOnInput->False,
         DynamicUpdating->True], "Panel",
        StripOnInput->False,
        Background->None]},
      {
       ItemBox[
        TagBox[
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
         Short[#, 5]& ],
        Background->GrayLevel[1],
        BaseStyle->{Deployed -> False},
        Frame->True,
        FrameStyle->GrayLevel[0, 0.2],
        StripOnInput->False]},
      {
       RowBox[{
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
             StandardForm],
            ImageSizeCache->{47., {0., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, 5/2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
             StandardForm],
            ImageSizeCache->{53., {0., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, 5 2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
             StandardForm],
            ImageSizeCache->{39., {0., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, Infinity],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
             StandardForm],
            ImageSizeCache->{69., {0., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetOptions[
            FrontEnd`$FrontEnd, 
             FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
            FrontEnd`FrontEndToken["PreferencesDialog"]}],
         Evaluator->None,
         Method->"Preemptive"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[1.2]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    DefaultBaseStyle->{},
    FrameMargins->5],
   Deploy,
   DefaultBaseStyle->{Deployed -> True}],
  Out[17]]], "Output",
 CellChangeTimes->{
  3.4809334494800777`*^9},ExpressionUUID->"e3624ab1-fae8-43e8-b13a-\
4a2cc5f27ac8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.480933450758684*^9, 
  3.4809334528471003`*^9}},ExpressionUUID->"a6979305-d047-4634-9bd3-\
969bbd1e3cb6"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.480933453756077*^9},ExpressionUUID->"f53bd388-b231-4e22-982a-\
c671ff260515"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "shortplucker", "]"}]], "Input",
 CellChangeTimes->{{3.4809334548247023`*^9, 
  3.480933458361225*^9}},ExpressionUUID->"7d287fda-9af3-468f-9115-\
051023c2150d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.480933459390708*^9, 
  3.4809335311031*^9},ExpressionUUID->"4e25d6c7-88d9-4bdc-aabd-202e4dfcb96b"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{897, 577},
WindowMargins->{{Automatic, 141}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"12.3 for Mac OS X x86 (64-bit) (July 9, 2021)",
StyleDefinitions->FrontEnd`FileName[{"Book"}, "Textbook.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"64413ba0-d0ee-4ff1-90f3-470c3fc640d6"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 331, 8, 125, "Title",ExpressionUUID->"932184fb-edc0-4e22-9b2e-b17d71a5f2e3"],
Cell[CellGroupData[{
Cell[923, 34, 282, 6, 55, "Section",ExpressionUUID->"53450679-dcac-46e7-a69b-58eec057524c"],
Cell[CellGroupData[{
Cell[1230, 44, 434, 8, 47, "Subsection",ExpressionUUID->"3ea58a94-b64a-4152-ade8-75c2e2c60728"],
Cell[1667, 54, 2128, 60, 127, "Input",ExpressionUUID->"55947ec3-25b5-42e1-a643-19f26c69e0de"],
Cell[3798, 116, 2400, 62, 151, "Code",ExpressionUUID->"b8ba4229-c782-45f1-b208-96a527d0816a",
 InitializationCell->False],
Cell[6201, 180, 4558, 127, 184, "Input",ExpressionUUID->"ad07b7f3-99bf-465f-8fa1-601c5c383059"],
Cell[10762, 309, 352, 10, 31, "Input",ExpressionUUID->"cdb206e2-c443-45e5-a50a-b0f6d3942dc5"],
Cell[11117, 321, 802, 25, 31, "Input",ExpressionUUID->"17c173a6-6bfe-4789-9a0a-6e2b567132d8"],
Cell[11922, 348, 1777, 55, 57, "Input",ExpressionUUID->"fb4b594f-ff4c-4e25-9d1e-1d9a0635b2f3"],
Cell[13702, 405, 389, 9, 31, "Input",ExpressionUUID->"5fda82fe-22ed-48ad-846d-729a317d35eb"],
Cell[14094, 416, 690, 20, 31, "Input",ExpressionUUID->"967422e9-3bbe-4ecb-93a6-57216824853f"],
Cell[14787, 438, 728, 19, 51, "Input",ExpressionUUID->"bfc780d4-d8c1-455b-a681-abab1584a17f"],
Cell[15518, 459, 620, 18, 31, "Input",ExpressionUUID->"62e0bcd9-5062-4a3d-98d1-66be1210b24d"],
Cell[16141, 479, 584, 19, 31, "Input",ExpressionUUID->"faccaf94-32fc-4506-a8a6-191899c61118"],
Cell[16728, 500, 1092, 34, 89, "Input",ExpressionUUID->"244fbb8d-66f0-461c-9d01-fde71dfa35af"],
Cell[17823, 536, 1305, 30, 31, "Input",ExpressionUUID->"925c45da-c331-4337-b387-bee83bf40d4e"],
Cell[19131, 568, 1166, 29, 89, "Input",ExpressionUUID->"d7599dba-b102-4299-912c-d7d7be2d70be"],
Cell[20300, 599, 2897, 77, 203, "Input",ExpressionUUID->"18f2ed73-25ca-42ab-92b0-047e0d1fff6a"],
Cell[23200, 678, 1059, 32, 70, "Input",ExpressionUUID->"eef725f6-cae1-4d5f-a615-4b2b2a362b21"],
Cell[24262, 712, 918, 29, 31, "Input",ExpressionUUID->"8e98905b-5987-4407-971f-0a6c6a5fae3e"],
Cell[25183, 743, 2484, 66, 146, "Input",ExpressionUUID->"e2e5c0e4-8920-4d32-98d8-befe7bc3be0b"],
Cell[27670, 811, 731, 21, 31, "Input",ExpressionUUID->"ff9ac8a7-4ccf-4bc7-a7f6-fe4ffa5cacc2"],
Cell[28404, 834, 846, 24, 31, "Input",ExpressionUUID->"16299808-9c05-4881-ab58-498146fbd880"],
Cell[29253, 860, 2781, 73, 146, "Input",ExpressionUUID->"e424e03e-37f0-4455-a5b9-d4963d2423e9"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32083, 939, 306, 5, 55, "Section",ExpressionUUID->"2462f245-132d-4900-aa77-6a5b7f12d306"],
Cell[32392, 946, 341, 7, 35, "Text",ExpressionUUID->"a2e658a2-a344-4285-8713-6e56b8456103"],
Cell[32736, 955, 2128, 60, 127, "Input",ExpressionUUID->"27ed7e9a-fcea-4045-b1ef-5e8d173e26d3"],
Cell[34867, 1017, 659, 11, 50, "Text",ExpressionUUID->"f78dc5c4-fee2-4ae5-b867-e344ff100339"],
Cell[35529, 1030, 2400, 62, 151, "Code",ExpressionUUID->"45838e61-9f2b-4b46-b5f6-08bda6be3662",
 InitializationCell->False]
}, Closed]],
Cell[CellGroupData[{
Cell[37966, 1097, 282, 4, 35, "Section",ExpressionUUID->"d4be86f3-072b-4714-892e-23ca8850e703"],
Cell[38251, 1103, 4558, 127, 184, "Input",ExpressionUUID->"a269d82d-6c35-4a7f-a5a2-5b98e8167a92"],
Cell[42812, 1232, 630, 11, 50, "Text",ExpressionUUID->"780076c6-3394-4590-a24f-5af40bf6e60e"],
Cell[43445, 1245, 479, 15, 51, "Input",ExpressionUUID->"35d5af76-c3eb-44ab-86c0-22f82c5769ed"]
}, Closed]],
Cell[CellGroupData[{
Cell[43961, 1265, 570, 10, 35, "Section",ExpressionUUID->"f569f65a-cc31-48f8-9a75-5f03b7a4b057"],
Cell[44534, 1277, 384, 8, 35, "Text",ExpressionUUID->"08879a3a-bfd1-4dec-8923-707814ec9da3"],
Cell[44921, 1287, 352, 10, 31, "Input",ExpressionUUID->"05b4a278-1f4e-4f0c-9c95-73f00f7d9fc8"],
Cell[45276, 1299, 802, 25, 31, "Input",ExpressionUUID->"58971509-f0d5-41a6-bc85-d735623d3389"],
Cell[46081, 1326, 347, 7, 35, "Text",ExpressionUUID->"a3c7a39c-4797-45dd-900c-c0edbbfb4ed7"],
Cell[46431, 1335, 549, 16, 31, "Input",ExpressionUUID->"3441e4fe-b249-4f73-a6f1-b1f0c93e0ecc"],
Cell[46983, 1353, 549, 16, 31, "Input",ExpressionUUID->"2c4037ae-2792-4e7f-9383-d033f90b8da3"],
Cell[47535, 1371, 373, 7, 35, "Text",ExpressionUUID->"0411a853-5c51-457e-abac-d4a86729905e"],
Cell[47911, 1380, 1777, 55, 57, "Input",ExpressionUUID->"19720267-7989-4c3c-8567-8265a945239c"]
}, Closed]],
Cell[CellGroupData[{
Cell[49725, 1440, 287, 4, 35, "Section",ExpressionUUID->"47a31417-6517-4928-b806-038e81ee0253"],
Cell[50015, 1446, 231, 6, 20, "Text",ExpressionUUID->"2001f66c-5189-442d-bcd1-18e24f7af045"],
Cell[50249, 1454, 426, 12, 31, "Input",ExpressionUUID->"1307b1af-ae60-42b9-ba7a-9558e18a8600"],
Cell[50678, 1468, 200, 3, 20, "Text",ExpressionUUID->"ac787c38-f1e9-4b0f-87ae-3a397607247e"],
Cell[CellGroupData[{
Cell[50903, 1475, 296, 7, 31, "Input",ExpressionUUID->"1be9d295-15af-48fc-b0d9-bc0b1f4dab16"],
Cell[51202, 1484, 396, 8, 31, "Output",ExpressionUUID->"70cbfd95-3e30-4f14-a599-3f9960b38d64"]
}, Open  ]],
Cell[51613, 1495, 262, 6, 20, "Text",ExpressionUUID->"4faf4d1f-b58a-4b66-b192-0afa93e2f874"],
Cell[51878, 1503, 1249, 35, 51, "Input",ExpressionUUID->"35004d9a-b752-4e83-bbf4-f471fa068422"],
Cell[53130, 1540, 429, 10, 35, "Text",ExpressionUUID->"77194004-621e-4ddc-af3c-af3faec6b799"],
Cell[53562, 1552, 1306, 37, 51, "Input",ExpressionUUID->"9dd67e19-7f1d-41a0-895d-01a08815943c"],
Cell[54871, 1591, 283, 6, 20, "Text",ExpressionUUID->"c156bf81-0064-417c-9c32-e1f549d971d3"],
Cell[CellGroupData[{
Cell[55179, 1601, 244, 5, 31, "Input",ExpressionUUID->"ac1f84d4-cfc7-41b1-884e-3645491efc2b"],
Cell[55426, 1608, 395, 9, 31, "Output",ExpressionUUID->"d2562d40-1247-4607-94c8-860eff1e4f0b"]
}, Open  ]],
Cell[55836, 1620, 186, 3, 20, "Text",ExpressionUUID->"34743b5e-cdc9-4ef2-bb9c-fb58ac7967f5"],
Cell[56025, 1625, 458, 12, 31, "Input",ExpressionUUID->"80a94111-6a14-4d5e-b782-54179dd6524d"],
Cell[56486, 1639, 144, 3, 20, "Text",ExpressionUUID->"77e9e94d-b316-4a2b-9a60-ccb57c3a2ea1"],
Cell[56633, 1644, 201, 3, 20, "Text",ExpressionUUID->"cae6c145-cd5b-42b4-9a1c-8dfe89b9d324"],
Cell[56837, 1649, 389, 9, 31, "Input",ExpressionUUID->"e46926d9-59c6-4405-9acb-10667df5da35"],
Cell[57229, 1660, 214, 5, 20, "Text",ExpressionUUID->"1afc01de-dcc0-48fa-8358-1b9f1df9b289"],
Cell[CellGroupData[{
Cell[57468, 1669, 504, 14, 31, "Input",ExpressionUUID->"9e493f74-cc17-408a-bba7-6f33658644e8"],
Cell[57975, 1685, 708, 20, 32, "Output",ExpressionUUID->"834da46c-caa3-4714-9286-a77a4371f340"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58720, 1710, 206, 3, 31, "Input",ExpressionUUID->"676daf9a-3bfd-4ebf-8e0c-c800a0281d10"],
Cell[58929, 1715, 705, 20, 32, "Output",ExpressionUUID->"e079e611-3741-4908-be48-6098c680065f"]
}, Open  ]],
Cell[59649, 1738, 370, 8, 20, "Text",ExpressionUUID->"65b362d0-c028-48c0-8a88-3b10ed10b609"],
Cell[60022, 1748, 900, 25, 31, "Input",ExpressionUUID->"ae71127c-6f76-4e19-b366-c6fd2e502dd0"],
Cell[60925, 1775, 335, 7, 35, "Text",ExpressionUUID->"9c7d0a9c-e51a-4c55-874a-36c61120516a"],
Cell[61263, 1784, 690, 20, 31, "Input",ExpressionUUID->"452d7b86-7699-40e7-bca8-093f3dd0ad7f"],
Cell[61956, 1806, 561, 15, 31, "Input",ExpressionUUID->"bc33048d-02e3-4168-9c93-9e389d84302f"],
Cell[62520, 1823, 728, 19, 51, "Input",ExpressionUUID->"b7409f8a-faf8-4ebb-9519-ede3356bc685"],
Cell[63251, 1844, 578, 15, 31, "Input",ExpressionUUID->"3c697f80-caca-4f71-be7e-bcef1ef675fa"],
Cell[63832, 1861, 593, 15, 31, "Input",ExpressionUUID->"ef8ad124-65e8-45fd-98ac-7bfd4c20d632"],
Cell[64428, 1878, 864, 24, 51, "Input",ExpressionUUID->"aaf3b60e-b0ff-446a-a79f-0b75106a8bb4"]
}, Closed]],
Cell[CellGroupData[{
Cell[65329, 1907, 289, 4, 35, "Section",ExpressionUUID->"aa99fce7-63c3-4464-84ae-4e2c3aa63fe0"],
Cell[65621, 1913, 234, 6, 20, "Text",ExpressionUUID->"6025d6f3-2b8b-4a99-96e3-ccb7342cd3cd"],
Cell[65858, 1921, 620, 18, 31, "Input",ExpressionUUID->"8a99caec-f9ac-4c5d-803b-a1d636bff072"],
Cell[66481, 1941, 460, 8, 35, "Text",ExpressionUUID->"6d180c02-f2e4-459f-8a11-e03ef06c78e5"],
Cell[CellGroupData[{
Cell[66966, 1953, 202, 3, 31, "Input",ExpressionUUID->"f6eed1be-715f-44fb-b2c2-4b1d287d249d"],
Cell[67171, 1958, 353, 7, 48, "Output",ExpressionUUID->"56038c76-82db-4614-b547-3870450aade4"]
}, Open  ]],
Cell[67539, 1968, 335, 7, 35, "Text",ExpressionUUID->"60968746-b200-4f24-8204-31a7717b547c"],
Cell[67877, 1977, 584, 19, 31, "Input",ExpressionUUID->"010cff67-0958-4436-8541-649b247a6340"],
Cell[68464, 1998, 218, 5, 20, "Text",ExpressionUUID->"6dc4e302-61bf-4753-abed-45c196f255fd"],
Cell[CellGroupData[{
Cell[68707, 2007, 277, 6, 31, "Input",ExpressionUUID->"5a21f881-01cd-4b21-8e95-97b6110d4536"],
Cell[68987, 2015, 437, 12, 32, "Output",ExpressionUUID->"1c1c5404-942d-473a-ad57-457c73f71b4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69461, 2032, 204, 3, 31, "Input",ExpressionUUID->"e92c7a41-f315-4fdf-a4ab-530d1f2987f5"],
Cell[69668, 2037, 1825, 58, 57, "Output",ExpressionUUID->"1a696847-5ab7-4c1c-a21f-fcfadc95333b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71530, 2100, 202, 3, 31, "Input",ExpressionUUID->"a7353906-8fe2-46aa-b62b-d5228ce88b6b"],
Cell[71735, 2105, 1906, 59, 57, "Output",ExpressionUUID->"a0d081e7-15e0-4a8e-b40b-f6654ee0688e"]
}, Open  ]],
Cell[73656, 2167, 375, 8, 20, "Text",ExpressionUUID->"13f85530-63e1-4d94-8263-df61623bf08d"],
Cell[74034, 2177, 1092, 34, 89, "Input",ExpressionUUID->"36fa3f0d-bc6b-4fa4-a46f-8b4ba331ea29"],
Cell[CellGroupData[{
Cell[75151, 2215, 392, 10, 31, "Input",ExpressionUUID->"b811db2e-0b8e-438d-b69e-0f0cec2ad838"],
Cell[75546, 2227, 10547, 313, 144, "Output",ExpressionUUID->"07310c2d-a7fc-4238-8756-995814b264be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86130, 2545, 201, 3, 31, "Input",ExpressionUUID->"fe0a9fdd-2867-459a-8619-036f42f24105"],
Cell[86334, 2550, 10899, 316, 144, "Output",ExpressionUUID->"f155b3fd-20d7-44b5-b369-f9aed78e3ab9"]
}, Open  ]],
Cell[97248, 2869, 499, 9, 35, "Text",ExpressionUUID->"444b3bdf-54d5-4b22-8b29-7c2e1fb70183"],
Cell[97750, 2880, 1305, 30, 31, "Input",ExpressionUUID->"48bda7f2-f66d-4763-8cfd-5e5604198b4f"],
Cell[99058, 2912, 880, 16, 95, "Text",ExpressionUUID->"07180984-a8dc-49b1-aa7d-d24d6cabdd22"],
Cell[CellGroupData[{
Cell[99963, 2932, 465, 11, 31, "Input",ExpressionUUID->"c318a3ae-75d1-459e-858a-bdc61f95a047"],
Cell[100431, 2945, 8738, 258, 122, "Output",ExpressionUUID->"f8553e38-9f1a-4fba-8659-b1311b1fa9f3"]
}, Open  ]],
Cell[109184, 3206, 526, 9, 35, "Text",ExpressionUUID->"7cd90176-9519-40d7-82d0-d026c5624afc"]
}, Closed]],
Cell[CellGroupData[{
Cell[109747, 3220, 373, 6, 35, "Section",ExpressionUUID->"906e0329-2e5b-4de9-8093-b93ea60d2f08"],
Cell[CellGroupData[{
Cell[110145, 3230, 181, 3, 32, "Subsection",ExpressionUUID->"ffce737d-6a20-489b-88b9-deb3ff16789e"],
Cell[110329, 3235, 1166, 29, 89, "Input",ExpressionUUID->"24266fd7-76fd-4c11-8ec8-30f19da0a085"],
Cell[111498, 3266, 313, 7, 20, "Text",ExpressionUUID->"a06e8795-8ce2-4ed9-85d0-9364b1ed8c72"],
Cell[CellGroupData[{
Cell[111836, 3277, 316, 8, 31, "Input",ExpressionUUID->"676ea30d-147f-4ab5-bb44-69d780f7715d"],
Cell[112155, 3287, 462, 10, 48, "Output",ExpressionUUID->"fbc9f559-9546-4de5-a458-f0cea8519e57"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112654, 3302, 383, 8, 31, "Input",ExpressionUUID->"173ec342-a6da-4be5-9ac6-89bef7d810dd"],
Cell[113040, 3312, 669, 16, 51, "Output",ExpressionUUID->"b42b095c-d009-4ce0-bb1b-7ef6d066f086"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[113758, 3334, 278, 4, 32, "Subsection",ExpressionUUID->"56be3213-6911-40b2-933f-2920b17fe612"],
Cell[114039, 3340, 168, 3, 20, "Text",ExpressionUUID->"1fc85f3f-ec2f-45d4-be6c-e003880fbed1"],
Cell[114210, 3345, 2897, 77, 203, "Input",ExpressionUUID->"25882765-c576-4d1b-b71d-d2b1eecc55f6"],
Cell[117110, 3424, 225, 5, 20, "Text",ExpressionUUID->"59f412e7-6027-4871-b3ef-ef4402873403"],
Cell[CellGroupData[{
Cell[117360, 3433, 498, 12, 51, "Input",ExpressionUUID->"8448a587-9eed-4604-b16f-5c23142d590f"],
Cell[117861, 3447, 467, 8, 32, "Output",ExpressionUUID->"9477bdc2-e249-4cc0-837d-56debf546ae2"],
Cell[118331, 3457, 507, 9, 32, "Output",ExpressionUUID->"996632a9-72ae-4a15-8c9e-8fb95e23451a"]
}, Open  ]],
Cell[118853, 3469, 198, 3, 20, "Text",ExpressionUUID->"7a61c819-38d8-411f-a01f-61a8f6d07152"],
Cell[CellGroupData[{
Cell[119076, 3476, 230, 4, 31, "Input",ExpressionUUID->"191ae4ce-3716-47e1-8b83-5fa0d823c39b"],
Cell[119309, 3482, 1078, 31, 34, "Output",ExpressionUUID->"967e75dd-67b4-4e21-a6b3-499131164897"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120424, 3518, 281, 5, 31, "Input",ExpressionUUID->"61455e6e-d291-4f49-a5ce-676259d3a416"],
Cell[120708, 3525, 1113, 31, 34, "Output",ExpressionUUID->"2501db3a-cf2f-4623-8fd9-73aa65921de5"]
}, Open  ]],
Cell[121836, 3559, 179, 3, 20, "Text",ExpressionUUID->"1a76d72d-b422-4a50-bf9e-9a158d5f8ae5"],
Cell[CellGroupData[{
Cell[122040, 3566, 395, 9, 31, "Input",ExpressionUUID->"5bc5f79c-de4a-4932-bf6d-14d1dd4114e7"],
Cell[122438, 3577, 1475, 42, 34, "Output",ExpressionUUID->"220f271d-c03d-4c2f-be89-7b3efc8cd45a"]
}, Open  ]],
Cell[123928, 3622, 286, 6, 20, "Text",ExpressionUUID->"689ddc0b-cc38-418a-849b-d98d96e9ccd5"],
Cell[CellGroupData[{
Cell[124239, 3632, 208, 3, 31, "Input",ExpressionUUID->"1d1c4f59-3723-4f3a-a018-9d5ae08d6344"],
Cell[124450, 3637, 928, 25, 34, "Output",ExpressionUUID->"22ceee3d-bd31-4890-8297-c9d1a08e08f4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125427, 3668, 202, 3, 32, "Subsection",ExpressionUUID->"e76651a5-81ef-4c4c-b5b8-97c8b2147ba5"],
Cell[125632, 3673, 1059, 32, 70, "Input",ExpressionUUID->"c44cb01e-42c3-44c4-9da3-a8588868c9b9"],
Cell[126694, 3707, 382, 8, 35, "Text",ExpressionUUID->"d80f6f1d-2f63-410b-b31e-388a05c3679a"],
Cell[CellGroupData[{
Cell[127101, 3719, 402, 9, 31, "Input",ExpressionUUID->"1f8b5888-6012-4063-aebf-67eac56d7d38"],
Cell[127506, 3730, 897, 19, 48, "Output",ExpressionUUID->"614dca45-9e9b-42f5-b962-59ff6e2fdeef"]
}, Open  ]],
Cell[128418, 3752, 297, 6, 20, "Text",ExpressionUUID->"47a705ee-b254-4345-9c65-80118d5a297c"],
Cell[CellGroupData[{
Cell[128740, 3762, 329, 6, 31, "Input",ExpressionUUID->"3351d2cb-212e-4565-91a6-9f2b9a68d35d"],
Cell[129072, 3770, 410, 6, 31, "Output",ExpressionUUID->"b72c877d-7ba5-4595-86d0-3aa3095cd27d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129519, 3781, 311, 6, 31, "Input",ExpressionUUID->"be1068a0-efab-4400-bcec-3490f8e8b3ea"],
Cell[129833, 3789, 410, 6, 31, "Output",ExpressionUUID->"40ab1274-3be3-49c4-b3e0-7e811f2932a0"]
}, Open  ]],
Cell[130258, 3798, 157, 3, 20, "Text",ExpressionUUID->"04568aa1-c807-4a70-b0c9-7c45f2ec0aca"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[130464, 3807, 258, 4, 35, "Section",ExpressionUUID->"6959b01e-6495-4a4b-a443-608a188ecbc0"],
Cell[130725, 3813, 234, 6, 20, "Text",ExpressionUUID->"3e5c4871-31a0-4ba9-adf8-6ca332024cc4"],
Cell[130962, 3821, 918, 29, 31, "Input",ExpressionUUID->"7eec68e7-47a0-4d4f-984f-60c11c176e3a"],
Cell[131883, 3852, 246, 6, 20, "Text",ExpressionUUID->"10c23b7f-268f-4f92-9155-29dd57a01a3a"],
Cell[132132, 3860, 2484, 66, 146, "Input",ExpressionUUID->"8301f7de-0f62-40d7-991c-536bc96f8fec"],
Cell[134619, 3928, 304, 6, 20, "Text",ExpressionUUID->"a0ef2d73-35c5-4092-b8ff-49ce8ba4ab78"],
Cell[134926, 3936, 731, 21, 31, "Input",ExpressionUUID->"46911b0e-35a2-44d4-91cd-10e4be9d2ba8"]
}, Closed]],
Cell[CellGroupData[{
Cell[135694, 3962, 311, 6, 35, "Section",ExpressionUUID->"2307b480-ae8e-4ba7-938f-055e809ddbd0"],
Cell[CellGroupData[{
Cell[136030, 3972, 283, 6, 32, "Subsection",ExpressionUUID->"9780adfe-5289-4b91-977b-554addd2c749"],
Cell[CellGroupData[{
Cell[136338, 3982, 1229, 38, 70, "Input",ExpressionUUID->"08b40045-34f0-4db9-be5d-958e771d1140"],
Cell[137570, 4022, 894, 30, 34, "Output",ExpressionUUID->"3410fd99-7f24-4141-9884-be2831bb7cab"]
}, Open  ]],
Cell[138479, 4055, 255, 6, 20, "Text",ExpressionUUID->"619b9efa-32ee-46a5-a06d-7ea96af7564a"],
Cell[CellGroupData[{
Cell[138759, 4065, 196, 4, 31, "Input",ExpressionUUID->"c945d4e5-daa7-462c-a482-15a9f3e26062"],
Cell[138958, 4071, 1482, 40, 47, "Print",ExpressionUUID->"887349bf-52c4-41e5-9d81-a246f36f02cf"],
Cell[140443, 4113, 298, 9, 31, "Output",ExpressionUUID->"fa8f0363-5b58-4cad-ab22-b4be1b5d0c40"]
}, Open  ]],
Cell[140756, 4125, 298, 6, 20, "Text",ExpressionUUID->"595da33d-9ff1-426f-ba9c-16a7236eaf59"],
Cell[141057, 4133, 772, 22, 89, "Input",ExpressionUUID->"51c1d3a9-49eb-4360-94e8-79684b792bac"],
Cell[141832, 4157, 328, 5, 20, "Text",ExpressionUUID->"d1962a12-b432-48b7-a397-219d73ae383e"],
Cell[CellGroupData[{
Cell[142185, 4166, 203, 5, 31, "Input",ExpressionUUID->"f52efe5c-3c43-48c2-bd4c-fc926f94d5e2"],
Cell[142391, 4173, 180, 5, 32, "Output",ExpressionUUID->"f7e5c9bc-5cae-48b8-9591-57186501a4c4"]
}, Open  ]],
Cell[142586, 4181, 188, 3, 20, "Text",ExpressionUUID->"cb97c5ca-deab-4d1a-a14b-68df882b2a57"],
Cell[CellGroupData[{
Cell[142799, 4188, 571, 17, 31, "Input",ExpressionUUID->"d163919f-227b-4434-94da-b6582b19203c"],
Cell[143373, 4207, 176, 4, 31, "Output",ExpressionUUID->"8d0d1c3a-ee0c-439e-8a07-7c75ba2558db"]
}, Open  ]],
Cell[143564, 4214, 237, 6, 20, "Text",ExpressionUUID->"b544c459-bc64-4483-8c14-178007f9ced3"],
Cell[CellGroupData[{
Cell[143826, 4224, 203, 5, 31, "Input",ExpressionUUID->"f4c6f92c-3885-43ef-979a-ef17d5e1d6e6"],
Cell[144032, 4231, 246, 8, 32, "Output",ExpressionUUID->"ea5ee878-a245-4940-b744-0a3a6dd26b60"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144315, 4244, 594, 19, 31, "Input",ExpressionUUID->"18862b46-2711-4c27-a527-58ee1326ca31"],
Cell[144912, 4265, 157, 4, 31, "Output",ExpressionUUID->"3161169a-8386-4382-be7c-d7dfe510ae56"]
}, Open  ]],
Cell[145084, 4272, 261, 8, 50, "Text",ExpressionUUID->"b4ca8460-4543-45c3-a78d-3e781f33722d"],
Cell[145348, 4282, 989, 29, 51, "Input",ExpressionUUID->"609ca425-9ee1-4b8b-bd88-1525de05e86d"],
Cell[CellGroupData[{
Cell[146362, 4315, 205, 5, 31, "Input",ExpressionUUID->"03e64c73-a1e8-4c8f-b34d-edbd62b73f69"],
Cell[146570, 4322, 624, 21, 32, "Output",ExpressionUUID->"6eb103e2-ea27-471c-850c-b4272024f11e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147231, 4348, 203, 5, 31, "Input",ExpressionUUID->"d0fcfede-d6bc-477a-953e-1f883a3b08e3"],
Cell[147437, 4355, 908, 30, 32, "Output",ExpressionUUID->"5be23a0f-905f-4020-b24e-b9a6ce046736"]
}, Open  ]],
Cell[148360, 4388, 289, 6, 20, "Text",ExpressionUUID->"779ee1d2-483a-4cc5-bd79-4b4919dc368c"],
Cell[CellGroupData[{
Cell[148674, 4398, 656, 21, 31, "Input",ExpressionUUID->"032a56b2-17b8-451d-bf0b-f7790c3f27db"],
Cell[149333, 4421, 3148, 105, 78, "Output",ExpressionUUID->"9287dddd-e3bc-44fa-8bbd-11af948a8a82"]
}, Open  ]],
Cell[152496, 4529, 174, 3, 20, "Text",ExpressionUUID->"60f8443f-f062-42b4-8ed6-bdf5571bf245"],
Cell[CellGroupData[{
Cell[152695, 4536, 284, 7, 31, "Input",ExpressionUUID->"197fafcf-ba27-4fc7-8167-c4ee53531c7a"],
Cell[152982, 4545, 459, 10, 24, "Print",ExpressionUUID->"90ec19a3-b89b-49af-a563-75eb4a71f119"],
Cell[153444, 4557, 2646, 90, 54, "Output",ExpressionUUID->"3165a080-3245-4979-bfc2-1a5fda1ea5ee"]
}, Open  ]],
Cell[156105, 4650, 245, 4, 20, "Text",ExpressionUUID->"b80b965f-7c45-493b-b23c-64b5fcc1b7c7"],
Cell[CellGroupData[{
Cell[156375, 4658, 241, 6, 31, "Input",ExpressionUUID->"b515690f-bd71-4165-8938-ed0b58b1bf67"],
Cell[156619, 4666, 156, 3, 31, "Output",ExpressionUUID->"b25cafe2-cca5-4dc2-a3ae-f354bc1e7aa5"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[156836, 4676, 342, 5, 35, "Section",ExpressionUUID->"13b0b56a-c59f-47c1-b46a-a65b84636537"],
Cell[CellGroupData[{
Cell[157203, 4685, 261, 5, 32, "Subsection",ExpressionUUID->"94dd1e0d-c60e-45e8-8ea9-7d33a789ccb4"],
Cell[157467, 4692, 277, 6, 20, "Text",ExpressionUUID->"92bb98e4-4e7c-4aea-9b8f-5814b5a57f1c"],
Cell[157747, 4700, 846, 24, 31, "Input",ExpressionUUID->"dfcc65c9-701b-4d34-8dee-9d0c666460d5"],
Cell[158596, 4726, 297, 7, 20, "Text",ExpressionUUID->"2f464097-85d6-4131-a964-6ba506844b62"],
Cell[158896, 4735, 2781, 73, 146, "Input",ExpressionUUID->"2e670d66-3423-405f-aca4-404584b0eb7a"],
Cell[CellGroupData[{
Cell[161702, 4812, 310, 6, 31, "Input",ExpressionUUID->"9b5112cd-6c20-4938-a91a-94181f419f04"],
Cell[162015, 4820, 1348, 39, 32, "Output",ExpressionUUID->"a606576a-9b12-4690-a27f-9c37372e5483"]
}, Open  ]],
Cell[163378, 4862, 287, 7, 20, "Text",ExpressionUUID->"f9cf0498-56c4-49f5-84fa-ca6029a993a2"],
Cell[163668, 4871, 1108, 30, 31, "Input",ExpressionUUID->"6b221e5d-7176-480b-865a-d96bbc65ef80"],
Cell[164779, 4903, 795, 23, 31, "Input",ExpressionUUID->"b9b91a0a-1a41-4267-9fe3-7d19e1d72cd8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165611, 4931, 193, 3, 32, "Subsection",ExpressionUUID->"043c70f7-3b32-412c-8dee-618223bee49a"],
Cell[CellGroupData[{
Cell[165829, 4938, 718, 22, 31, "Input",ExpressionUUID->"4ef38287-c7a5-49fe-af3c-ee8a7358933e"],
Cell[166550, 4962, 1952, 59, 56, "Output",ExpressionUUID->"5e188b4a-86c7-4160-8f7d-8d059e72fcb3"]
}, Open  ]],
Cell[168517, 5024, 2147, 62, 76, "Input",ExpressionUUID->"82606764-0bba-4259-9ef4-c9627ebbc135"],
Cell[CellGroupData[{
Cell[170689, 5090, 163, 3, 31, "Input",ExpressionUUID->"d3b821ef-b67b-49de-9b8c-f5233228e113"],
Cell[170855, 5095, 4186, 121, 108, "Output",ExpressionUUID->"e3624ab1-fae8-43e8-b13a-4a2cc5f27ac8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175078, 5221, 189, 4, 31, "Input",ExpressionUUID->"a6979305-d047-4634-9bd3-969bbd1e3cb6"],
Cell[175270, 5227, 130, 3, 31, "Output",ExpressionUUID->"f53bd388-b231-4e22-982a-c671ff260515"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175437, 5235, 200, 4, 31, "Input",ExpressionUUID->"7d287fda-9af3-468f-9115-051023c2150d"],
Cell[175640, 5241, 148, 2, 31, "Output",ExpressionUUID->"4e25d6c7-88d9-4bdc-aabd-202e4dfcb96b"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

